from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.shared_set_status import SharedSetStatusEnum
from google.ads.googleads.v17.enums.types.shared_set_type import SharedSetTypeEnum

_M = TypeVar("_M")

class SharedSet(proto.Message):
    resource_name: str
    id: int
    type_: SharedSetTypeEnum.SharedSetType
    name: str
    status: SharedSetStatusEnum.SharedSetStatus
    member_count: int
    reference_count: int
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        type_: SharedSetTypeEnum.SharedSetType = ...,
        name: str = ...,
        status: SharedSetStatusEnum.SharedSetStatus = ...,
        member_count: int = ...,
        reference_count: int = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "type_",
            "name",
            "status",
            "member_count",
            "reference_count",
        ],
    ) -> bool: ...



from .base import BillingSetupServiceTransport as BillingSetupServiceTransport
from .grpc import BillingSetupServiceGrpcTransport as BillingSetupServiceGrpcTransport

__all__ = ["BillingSetupServiceTransport", "BillingSetupServiceGrpcTransport"]



from .base import UserDataServiceTransport as UserDataServiceTransport
from .grpc import UserDataServiceGrpcTransport as UserDataServiceGrpcTransport

__all__ = ["UserDataServiceTransport", "UserDataServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.protobuf.field_mask_pb2 import FieldMask
from typing_extensions import Literal

from google.ads.googleads.v16.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v16.resources.types.custom_conversion_goal import (
    CustomConversionGoal,
)

_M = TypeVar("_M")

class CustomConversionGoalOperation(proto.Message):
    update_mask: FieldMask
    create: CustomConversionGoal
    update: CustomConversionGoal
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        update_mask: FieldMask = ...,
        create: CustomConversionGoal = ...,
        update: CustomConversionGoal = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["update_mask", "create", "update", "remove"]
    ) -> bool: ...

class MutateCustomConversionGoalResult(proto.Message):
    resource_name: str
    custom_conversion_goal: CustomConversionGoal
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        custom_conversion_goal: CustomConversionGoal = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "custom_conversion_goal"]
    ) -> bool: ...

class MutateCustomConversionGoalsRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[CustomConversionGoalOperation]
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[CustomConversionGoalOperation] = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id", "operations", "validate_only", "response_content_type"
        ],
    ) -> bool: ...

class MutateCustomConversionGoalsResponse(proto.Message):
    results: MutableSequence[MutateCustomConversionGoalResult]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        results: MutableSequence[MutateCustomConversionGoalResult] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["results"]
    ) -> bool: ...



from .base import AdParameterServiceTransport as AdParameterServiceTransport
from .grpc import AdParameterServiceGrpcTransport as AdParameterServiceGrpcTransport

__all__ = ["AdParameterServiceTransport", "AdParameterServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class Value(proto.Message):
    boolean_value: bool
    int64_value: int
    float_value: float
    double_value: float
    string_value: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        boolean_value: bool = ...,
        int64_value: int = ...,
        float_value: float = ...,
        double_value: float = ...,
        string_value: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "boolean_value",
            "int64_value",
            "float_value",
            "double_value",
            "string_value",
        ],
    ) -> bool: ...



from .base import (
    ThirdPartyAppAnalyticsLinkServiceTransport as ThirdPartyAppAnalyticsLinkServiceTransport,
)
from .grpc import (
    ThirdPartyAppAnalyticsLinkServiceGrpcTransport as ThirdPartyAppAnalyticsLinkServiceGrpcTransport,
)

__all__ = [
    "ThirdPartyAppAnalyticsLinkServiceTransport",
    "ThirdPartyAppAnalyticsLinkServiceGrpcTransport",
]



from .base import RecommendationServiceTransport as RecommendationServiceTransport
from .grpc import (
    RecommendationServiceGrpcTransport as RecommendationServiceGrpcTransport,
)

__all__ = ["RecommendationServiceTransport", "RecommendationServiceGrpcTransport"]



import types
from typing import Dict, MutableSequence, Sequence, Tuple, Type

from _typeshed import Incomplete
from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    operation,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v17.services.services.experiment_service import pagers
from google.ads.googleads.v17.services.types import experiment_service

from .transports.base import ExperimentServiceTransport

__all__ = ["ExperimentServiceClient"]

class ExperimentServiceClientMeta(type):
    def get_transport_class(
        cls, label: str | None = None
    ) -> type[ExperimentServiceTransport]: ...

class ExperimentServiceClient(metaclass=ExperimentServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @property
    def transport(self) -> ExperimentServiceTransport: ...
    def __enter__(self) -> ExperimentServiceClient: ...
    def __exit__(
        self,
        type: type[BaseException] | None,
        value: BaseException | None,
        traceback: types.TracebackType | None,
    ) -> None: ...
    @staticmethod
    def campaign_path(customer_id: str, campaign_id: str) -> str: ...
    @staticmethod
    def parse_campaign_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def campaign_budget_path(customer_id: str, campaign_budget_id: str) -> str: ...
    @staticmethod
    def parse_campaign_budget_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def experiment_path(customer_id: str, trial_id: str) -> str: ...
    @staticmethod
    def parse_experiment_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str | ExperimentServiceTransport | None = None,
        client_options: client_options_lib.ClientOptions | dict | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    def mutate_experiments(
        self,
        request: experiment_service.MutateExperimentsRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        operations: MutableSequence[experiment_service.ExperimentOperation]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> experiment_service.MutateExperimentsResponse: ...
    def end_experiment(
        self,
        request: experiment_service.EndExperimentRequest | dict | None = None,
        *,
        experiment: str | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> None: ...
    def list_experiment_async_errors(
        self,
        request: experiment_service.ListExperimentAsyncErrorsRequest
        | dict
        | None = None,
        *,
        resource_name: str | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> pagers.ListExperimentAsyncErrorsPager: ...
    def graduate_experiment(
        self,
        request: experiment_service.GraduateExperimentRequest | dict | None = None,
        *,
        experiment: str | None = None,
        campaign_budget_mappings: MutableSequence[
            experiment_service.CampaignBudgetMapping
        ]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> None: ...
    def schedule_experiment(
        self,
        request: experiment_service.ScheduleExperimentRequest | dict | None = None,
        *,
        resource_name: str | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> operation.Operation: ...
    def promote_experiment(
        self,
        request: experiment_service.PromoteExperimentRequest | dict | None = None,
        *,
        resource_name: str | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> operation.Operation: ...



from .base import CustomerAssetSetServiceTransport as CustomerAssetSetServiceTransport
from .grpc import (
    CustomerAssetSetServiceGrpcTransport as CustomerAssetSetServiceGrpcTransport,
)

__all__ = ["CustomerAssetSetServiceTransport", "CustomerAssetSetServiceGrpcTransport"]



from .base import AdGroupFeedServiceTransport as AdGroupFeedServiceTransport
from .grpc import AdGroupFeedServiceGrpcTransport as AdGroupFeedServiceGrpcTransport

__all__ = ["AdGroupFeedServiceTransport", "AdGroupFeedServiceGrpcTransport"]



from .base import AdGroupAssetSetServiceTransport as AdGroupAssetSetServiceTransport
from .grpc import (
    AdGroupAssetSetServiceGrpcTransport as AdGroupAssetSetServiceGrpcTransport,
)

__all__ = ["AdGroupAssetSetServiceTransport", "AdGroupAssetSetServiceGrpcTransport"]



from .base import CampaignFeedServiceTransport as CampaignFeedServiceTransport
from .grpc import CampaignFeedServiceGrpcTransport as CampaignFeedServiceGrpcTransport

__all__ = ["CampaignFeedServiceTransport", "CampaignFeedServiceGrpcTransport"]



from .base import KeywordPlanServiceTransport as KeywordPlanServiceTransport
from .grpc import KeywordPlanServiceGrpcTransport as KeywordPlanServiceGrpcTransport

__all__ = ["KeywordPlanServiceTransport", "KeywordPlanServiceGrpcTransport"]



from .base import AdGroupLabelServiceTransport as AdGroupLabelServiceTransport
from .grpc import AdGroupLabelServiceGrpcTransport as AdGroupLabelServiceGrpcTransport

__all__ = ["AdGroupLabelServiceTransport", "AdGroupLabelServiceGrpcTransport"]



from .base import AdGroupAdServiceTransport as AdGroupAdServiceTransport
from .grpc import AdGroupAdServiceGrpcTransport as AdGroupAdServiceGrpcTransport

__all__ = ["AdGroupAdServiceTransport", "AdGroupAdServiceGrpcTransport"]



from .base import ReachPlanServiceTransport as ReachPlanServiceTransport
from .grpc import ReachPlanServiceGrpcTransport as ReachPlanServiceGrpcTransport

__all__ = ["ReachPlanServiceTransport", "ReachPlanServiceGrpcTransport"]



from .base import (
    KeywordPlanAdGroupServiceTransport as KeywordPlanAdGroupServiceTransport,
)
from .grpc import (
    KeywordPlanAdGroupServiceGrpcTransport as KeywordPlanAdGroupServiceGrpcTransport,
)

__all__ = [
    "KeywordPlanAdGroupServiceTransport",
    "KeywordPlanAdGroupServiceGrpcTransport",
]



from .base import CustomerAssetServiceTransport as CustomerAssetServiceTransport
from .grpc import CustomerAssetServiceGrpcTransport as CustomerAssetServiceGrpcTransport

__all__ = ["CustomerAssetServiceTransport", "CustomerAssetServiceGrpcTransport"]



from .base import (
    SmartCampaignSuggestServiceTransport as SmartCampaignSuggestServiceTransport,
)
from .grpc import (
    SmartCampaignSuggestServiceGrpcTransport as SmartCampaignSuggestServiceGrpcTransport,
)

__all__ = [
    "SmartCampaignSuggestServiceTransport",
    "SmartCampaignSuggestServiceGrpcTransport",
]



from .base import (
    KeywordPlanAdGroupKeywordServiceTransport as KeywordPlanAdGroupKeywordServiceTransport,
)
from .grpc import (
    KeywordPlanAdGroupKeywordServiceGrpcTransport as KeywordPlanAdGroupKeywordServiceGrpcTransport,
)

__all__ = [
    "KeywordPlanAdGroupKeywordServiceTransport",
    "KeywordPlanAdGroupKeywordServiceGrpcTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.common.types.custom_parameter import CustomParameter
from google.ads.googleads.v16.common.types.feed_common import Money
from google.ads.googleads.v16.enums.types.app_store import AppStoreEnum
from google.ads.googleads.v16.enums.types.call_conversion_reporting_state import (
    CallConversionReportingStateEnum,
)
from google.ads.googleads.v16.enums.types.price_extension_price_qualifier import (
    PriceExtensionPriceQualifierEnum,
)
from google.ads.googleads.v16.enums.types.price_extension_price_unit import (
    PriceExtensionPriceUnitEnum,
)
from google.ads.googleads.v16.enums.types.price_extension_type import (
    PriceExtensionTypeEnum,
)
from google.ads.googleads.v16.enums.types.promotion_extension_discount_modifier import (
    PromotionExtensionDiscountModifierEnum,
)
from google.ads.googleads.v16.enums.types.promotion_extension_occasion import (
    PromotionExtensionOccasionEnum,
)

_M = TypeVar("_M")

class AffiliateLocationFeedItem(proto.Message):
    business_name: str
    address_line_1: str
    address_line_2: str
    city: str
    province: str
    postal_code: str
    country_code: str
    phone_number: str
    chain_id: int
    chain_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name: str = ...,
        address_line_1: str = ...,
        address_line_2: str = ...,
        city: str = ...,
        province: str = ...,
        postal_code: str = ...,
        country_code: str = ...,
        phone_number: str = ...,
        chain_id: int = ...,
        chain_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "business_name",
            "address_line_1",
            "address_line_2",
            "city",
            "province",
            "postal_code",
            "country_code",
            "phone_number",
            "chain_id",
            "chain_name",
        ],
    ) -> bool: ...

class AppFeedItem(proto.Message):
    link_text: str
    app_id: str
    app_store: AppStoreEnum.AppStore
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    tracking_url_template: str
    url_custom_parameters: MutableSequence[CustomParameter]
    final_url_suffix: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        link_text: str = ...,
        app_id: str = ...,
        app_store: AppStoreEnum.AppStore = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
        tracking_url_template: str = ...,
        url_custom_parameters: MutableSequence[CustomParameter] = ...,
        final_url_suffix: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "link_text",
            "app_id",
            "app_store",
            "final_urls",
            "final_mobile_urls",
            "tracking_url_template",
            "url_custom_parameters",
            "final_url_suffix",
        ],
    ) -> bool: ...

class CallFeedItem(proto.Message):
    phone_number: str
    country_code: str
    call_tracking_enabled: bool
    call_conversion_action: str
    call_conversion_tracking_disabled: bool
    call_conversion_reporting_state: (
        CallConversionReportingStateEnum.CallConversionReportingState
    )
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        phone_number: str = ...,
        country_code: str = ...,
        call_tracking_enabled: bool = ...,
        call_conversion_action: str = ...,
        call_conversion_tracking_disabled: bool = ...,
        call_conversion_reporting_state: CallConversionReportingStateEnum.CallConversionReportingState = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "phone_number",
            "country_code",
            "call_tracking_enabled",
            "call_conversion_action",
            "call_conversion_tracking_disabled",
            "call_conversion_reporting_state",
        ],
    ) -> bool: ...

class CalloutFeedItem(proto.Message):
    callout_text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        callout_text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["callout_text"]
    ) -> bool: ...

class HotelCalloutFeedItem(proto.Message):
    text: str
    language_code: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
        language_code: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["text", "language_code"]
    ) -> bool: ...

class ImageFeedItem(proto.Message):
    image_asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        image_asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["image_asset"]
    ) -> bool: ...

class LocationFeedItem(proto.Message):
    business_name: str
    address_line_1: str
    address_line_2: str
    city: str
    province: str
    postal_code: str
    country_code: str
    phone_number: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name: str = ...,
        address_line_1: str = ...,
        address_line_2: str = ...,
        city: str = ...,
        province: str = ...,
        postal_code: str = ...,
        country_code: str = ...,
        phone_number: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "business_name",
            "address_line_1",
            "address_line_2",
            "city",
            "province",
            "postal_code",
            "country_code",
            "phone_number",
        ],
    ) -> bool: ...

class PriceFeedItem(proto.Message):
    type_: PriceExtensionTypeEnum.PriceExtensionType
    price_qualifier: PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier
    tracking_url_template: str
    language_code: str
    price_offerings: MutableSequence[PriceOffer]
    final_url_suffix: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        type_: PriceExtensionTypeEnum.PriceExtensionType = ...,
        price_qualifier: PriceExtensionPriceQualifierEnum.PriceExtensionPriceQualifier = ...,
        tracking_url_template: str = ...,
        language_code: str = ...,
        price_offerings: MutableSequence[PriceOffer] = ...,
        final_url_suffix: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "type_",
            "price_qualifier",
            "tracking_url_template",
            "language_code",
            "price_offerings",
            "final_url_suffix",
        ],
    ) -> bool: ...

class PriceOffer(proto.Message):
    header: str
    description: str
    price: Money
    unit: PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        header: str = ...,
        description: str = ...,
        price: Money = ...,
        unit: PriceExtensionPriceUnitEnum.PriceExtensionPriceUnit = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "header", "description", "price", "unit", "final_urls", "final_mobile_urls"
        ],
    ) -> bool: ...

class PromotionFeedItem(proto.Message):
    promotion_target: str
    discount_modifier: (
        PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier
    )
    promotion_start_date: str
    promotion_end_date: str
    occasion: PromotionExtensionOccasionEnum.PromotionExtensionOccasion
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    tracking_url_template: str
    url_custom_parameters: MutableSequence[CustomParameter]
    final_url_suffix: str
    language_code: str
    percent_off: int
    money_amount_off: Money
    promotion_code: str
    orders_over_amount: Money
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        promotion_target: str = ...,
        discount_modifier: PromotionExtensionDiscountModifierEnum.PromotionExtensionDiscountModifier = ...,
        promotion_start_date: str = ...,
        promotion_end_date: str = ...,
        occasion: PromotionExtensionOccasionEnum.PromotionExtensionOccasion = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
        tracking_url_template: str = ...,
        url_custom_parameters: MutableSequence[CustomParameter] = ...,
        final_url_suffix: str = ...,
        language_code: str = ...,
        percent_off: int = ...,
        money_amount_off: Money = ...,
        promotion_code: str = ...,
        orders_over_amount: Money = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "promotion_target",
            "discount_modifier",
            "promotion_start_date",
            "promotion_end_date",
            "occasion",
            "final_urls",
            "final_mobile_urls",
            "tracking_url_template",
            "url_custom_parameters",
            "final_url_suffix",
            "language_code",
            "percent_off",
            "money_amount_off",
            "promotion_code",
            "orders_over_amount",
        ],
    ) -> bool: ...

class SitelinkFeedItem(proto.Message):
    link_text: str
    line1: str
    line2: str
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    tracking_url_template: str
    url_custom_parameters: MutableSequence[CustomParameter]
    final_url_suffix: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        link_text: str = ...,
        line1: str = ...,
        line2: str = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
        tracking_url_template: str = ...,
        url_custom_parameters: MutableSequence[CustomParameter] = ...,
        final_url_suffix: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "link_text",
            "line1",
            "line2",
            "final_urls",
            "final_mobile_urls",
            "tracking_url_template",
            "url_custom_parameters",
            "final_url_suffix",
        ],
    ) -> bool: ...

class StructuredSnippetFeedItem(proto.Message):
    header: str
    values: MutableSequence[str]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        header: str = ...,
        values: MutableSequence[str] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["header", "values"]
    ) -> bool: ...

class TextMessageFeedItem(proto.Message):
    business_name: str
    country_code: str
    phone_number: str
    text: str
    extension_text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name: str = ...,
        country_code: str = ...,
        phone_number: str = ...,
        text: str = ...,
        extension_text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "business_name", "country_code", "phone_number", "text", "extension_text"
        ],
    ) -> bool: ...



from .base import AssetServiceTransport as AssetServiceTransport
from .grpc import AssetServiceGrpcTransport as AssetServiceGrpcTransport

__all__ = ["AssetServiceTransport", "AssetServiceGrpcTransport"]



__all__ = [
    "AccessInvitationStatusEnum",
    "AccessReasonEnum",
    "AccessRoleEnum",
    "AccountBudgetProposalStatusEnum",
    "AccountBudgetProposalTypeEnum",
    "AccountBudgetStatusEnum",
    "AccountLinkStatusEnum",
    "AdCustomizerPlaceholderFieldEnum",
    "AdDestinationTypeEnum",
    "AdGroupAdPrimaryStatusEnum",
    "AdGroupAdPrimaryStatusReasonEnum",
    "AdGroupAdRotationModeEnum",
    "AdGroupAdStatusEnum",
    "AdGroupCriterionApprovalStatusEnum",
    "AdGroupCriterionStatusEnum",
    "AdGroupPrimaryStatusEnum",
    "AdGroupPrimaryStatusReasonEnum",
    "AdGroupStatusEnum",
    "AdGroupTypeEnum",
    "AdNetworkTypeEnum",
    "AdServingOptimizationStatusEnum",
    "AdStrengthEnum",
    "AdTypeEnum",
    "AdvertisingChannelSubTypeEnum",
    "AdvertisingChannelTypeEnum",
    "AffiliateLocationFeedRelationshipTypeEnum",
    "AffiliateLocationPlaceholderFieldEnum",
    "AgeRangeTypeEnum",
    "AndroidPrivacyInteractionTypeEnum",
    "AndroidPrivacyNetworkTypeEnum",
    "AppBiddingGoalEnum",
    "AppCampaignAppStoreEnum",
    "AppCampaignBiddingStrategyGoalTypeEnum",
    "AppPaymentModelTypeEnum",
    "AppPlaceholderFieldEnum",
    "AppStoreEnum",
    "AppUrlOperatingSystemTypeEnum",
    "AssetAutomationStatusEnum",
    "AssetAutomationTypeEnum",
    "AssetFieldTypeEnum",
    "AssetGroupPrimaryStatusEnum",
    "AssetGroupPrimaryStatusReasonEnum",
    "AssetGroupSignalApprovalStatusEnum",
    "AssetGroupStatusEnum",
    "AssetLinkPrimaryStatusEnum",
    "AssetLinkPrimaryStatusReasonEnum",
    "AssetLinkStatusEnum",
    "AssetOfflineEvaluationErrorReasonsEnum",
    "AssetPerformanceLabelEnum",
    "AssetSetAssetStatusEnum",
    "AssetSetLinkStatusEnum",
    "AssetSetStatusEnum",
    "AssetSetTypeEnum",
    "AssetSourceEnum",
    "AssetTypeEnum",
    "AsyncActionStatusEnum",
    "AttributionModelEnum",
    "AudienceInsightsDimensionEnum",
    "AudienceScopeEnum",
    "AudienceStatusEnum",
    "BatchJobStatusEnum",
    "BidModifierSourceEnum",
    "BiddingSourceEnum",
    "BiddingStrategyStatusEnum",
    "BiddingStrategySystemStatusEnum",
    "BiddingStrategyTypeEnum",
    "BillingSetupStatusEnum",
    "BrandRequestRejectionReasonEnum",
    "BrandSafetySuitabilityEnum",
    "BrandStateEnum",
    "BudgetCampaignAssociationStatusEnum",
    "BudgetDeliveryMethodEnum",
    "BudgetPeriodEnum",
    "BudgetStatusEnum",
    "BudgetTypeEnum",
    "CallConversionReportingStateEnum",
    "CallPlaceholderFieldEnum",
    "CallToActionTypeEnum",
    "CallTrackingDisplayLocationEnum",
    "CallTypeEnum",
    "CalloutPlaceholderFieldEnum",
    "CampaignCriterionStatusEnum",
    "CampaignDraftStatusEnum",
    "CampaignExperimentTypeEnum",
    "CampaignGroupStatusEnum",
    "CampaignPrimaryStatusEnum",
    "CampaignPrimaryStatusReasonEnum",
    "CampaignServingStatusEnum",
    "CampaignSharedSetStatusEnum",
    "CampaignStatusEnum",
    "ChainRelationshipTypeEnum",
    "ChangeClientTypeEnum",
    "ChangeEventResourceTypeEnum",
    "ChangeStatusOperationEnum",
    "ChangeStatusResourceTypeEnum",
    "ClickTypeEnum",
    "CombinedAudienceStatusEnum",
    "ConsentStatusEnum",
    "ContentLabelTypeEnum",
    "ConversionActionCategoryEnum",
    "ConversionActionCountingTypeEnum",
    "ConversionActionStatusEnum",
    "ConversionActionTypeEnum",
    "ConversionAdjustmentTypeEnum",
    "ConversionAttributionEventTypeEnum",
    "ConversionCustomVariableStatusEnum",
    "ConversionEnvironmentEnum",
    "ConversionLagBucketEnum",
    "ConversionOrAdjustmentLagBucketEnum",
    "ConversionOriginEnum",
    "ConversionTrackingStatusEnum",
    "ConversionValueRulePrimaryDimensionEnum",
    "ConversionValueRuleSetStatusEnum",
    "ConversionValueRuleStatusEnum",
    "ConvertingUserPriorEngagementTypeAndLtvBucketEnum",
    "CriterionCategoryChannelAvailabilityModeEnum",
    "CriterionCategoryLocaleAvailabilityModeEnum",
    "CriterionSystemServingStatusEnum",
    "CriterionTypeEnum",
    "CustomAudienceMemberTypeEnum",
    "CustomAudienceStatusEnum",
    "CustomAudienceTypeEnum",
    "CustomConversionGoalStatusEnum",
    "CustomInterestMemberTypeEnum",
    "CustomInterestStatusEnum",
    "CustomInterestTypeEnum",
    "CustomPlaceholderFieldEnum",
    "CustomerAcquisitionOptimizationModeEnum",
    "CustomerMatchUploadKeyTypeEnum",
    "CustomerPayPerConversionEligibilityFailureReasonEnum",
    "CustomerStatusEnum",
    "CustomizerAttributeStatusEnum",
    "CustomizerAttributeTypeEnum",
    "CustomizerValueStatusEnum",
    "DataDrivenModelStatusEnum",
    "DayOfWeekEnum",
    "DeviceEnum",
    "DisplayAdFormatSettingEnum",
    "DisplayUploadProductTypeEnum",
    "DistanceBucketEnum",
    "DsaPageFeedCriterionFieldEnum",
    "EducationPlaceholderFieldEnum",
    "ExperimentMetricDirectionEnum",
    "ExperimentMetricEnum",
    "ExperimentStatusEnum",
    "ExperimentTypeEnum",
    "ExtensionSettingDeviceEnum",
    "ExtensionTypeEnum",
    "ExternalConversionSourceEnum",
    "FeedAttributeTypeEnum",
    "FeedItemQualityApprovalStatusEnum",
    "FeedItemQualityDisapprovalReasonEnum",
    "FeedItemSetStatusEnum",
    "FeedItemSetStringFilterTypeEnum",
    "FeedItemStatusEnum",
    "FeedItemTargetDeviceEnum",
    "FeedItemTargetStatusEnum",
    "FeedItemTargetTypeEnum",
    "FeedItemValidationStatusEnum",
    "FeedLinkStatusEnum",
    "FeedMappingCriterionTypeEnum",
    "FeedMappingStatusEnum",
    "FeedOriginEnum",
    "FeedStatusEnum",
    "FlightPlaceholderFieldEnum",
    "FrequencyCapEventTypeEnum",
    "FrequencyCapLevelEnum",
    "FrequencyCapTimeUnitEnum",
    "GenderTypeEnum",
    "GeoTargetConstantStatusEnum",
    "GeoTargetingRestrictionEnum",
    "GeoTargetingTypeEnum",
    "GoalConfigLevelEnum",
    "GoogleAdsFieldCategoryEnum",
    "GoogleAdsFieldDataTypeEnum",
    "GoogleVoiceCallStatusEnum",
    "HotelAssetSuggestionStatusEnum",
    "HotelDateSelectionTypeEnum",
    "HotelPlaceholderFieldEnum",
    "HotelPriceBucketEnum",
    "HotelRateTypeEnum",
    "HotelReconciliationStatusEnum",
    "IdentityVerificationProgramEnum",
    "IdentityVerificationProgramStatusEnum",
    "ImagePlaceholderFieldEnum",
    "IncomeRangeTypeEnum",
    "InteractionEventTypeEnum",
    "InteractionTypeEnum",
    "InvoiceTypeEnum",
    "JobPlaceholderFieldEnum",
    "KeywordMatchTypeEnum",
    "KeywordPlanAggregateMetricTypeEnum",
    "KeywordPlanCompetitionLevelEnum",
    "KeywordPlanConceptGroupTypeEnum",
    "KeywordPlanForecastIntervalEnum",
    "KeywordPlanKeywordAnnotationEnum",
    "KeywordPlanNetworkEnum",
    "LabelStatusEnum",
    "LeadFormCallToActionTypeEnum",
    "LeadFormDesiredIntentEnum",
    "LeadFormFieldUserInputTypeEnum",
    "LeadFormPostSubmitCallToActionTypeEnum",
    "LegacyAppInstallAdAppStoreEnum",
    "LinkedAccountTypeEnum",
    "LinkedProductTypeEnum",
    "ListingGroupFilterCustomAttributeIndexEnum",
    "ListingGroupFilterListingSourceEnum",
    "ListingGroupFilterProductCategoryLevelEnum",
    "ListingGroupFilterProductChannelEnum",
    "ListingGroupFilterProductConditionEnum",
    "ListingGroupFilterProductTypeLevelEnum",
    "ListingGroupFilterTypeEnum",
    "ListingGroupTypeEnum",
    "ListingTypeEnum",
    "LocalPlaceholderFieldEnum",
    "LocalServicesBusinessRegistrationCheckRejectionReasonEnum",
    "LocalServicesBusinessRegistrationTypeEnum",
    "LocalServicesCreditStateEnum",
    "LocalServicesEmployeeStatusEnum",
    "LocalServicesEmployeeTypeEnum",
    "LocalServicesInsuranceRejectionReasonEnum",
    "LocalServicesLeadConversationTypeEnum",
    "LocalServicesLeadStatusEnum",
    "LocalServicesLeadTypeEnum",
    "LocalServicesLicenseRejectionReasonEnum",
    "LocalServicesParticipantTypeEnum",
    "LocalServicesVerificationArtifactStatusEnum",
    "LocalServicesVerificationArtifactTypeEnum",
    "LocalServicesVerificationStatusEnum",
    "LocationExtensionTargetingCriterionFieldEnum",
    "LocationGroupRadiusUnitsEnum",
    "LocationOwnershipTypeEnum",
    "LocationPlaceholderFieldEnum",
    "LocationSourceTypeEnum",
    "LocationStringFilterTypeEnum",
    "LookalikeExpansionLevelEnum",
    "ManagerLinkStatusEnum",
    "MatchingFunctionContextTypeEnum",
    "MatchingFunctionOperatorEnum",
    "MediaTypeEnum",
    "MessagePlaceholderFieldEnum",
    "MimeTypeEnum",
    "MinuteOfHourEnum",
    "MobileAppVendorEnum",
    "MobileDeviceTypeEnum",
    "MonthOfYearEnum",
    "NegativeGeoTargetTypeEnum",
    "OfflineConversionDiagnosticStatusEnum",
    "OfflineEventUploadClientEnum",
    "OfflineUserDataJobFailureReasonEnum",
    "OfflineUserDataJobMatchRateRangeEnum",
    "OfflineUserDataJobStatusEnum",
    "OfflineUserDataJobTypeEnum",
    "OperatingSystemVersionOperatorTypeEnum",
    "OptimizationGoalTypeEnum",
    "ParentalStatusTypeEnum",
    "PaymentModeEnum",
    "PerformanceMaxUpgradeStatusEnum",
    "PlaceholderTypeEnum",
    "PlacementTypeEnum",
    "PolicyApprovalStatusEnum",
    "PolicyReviewStatusEnum",
    "PolicyTopicEntryTypeEnum",
    "PolicyTopicEvidenceDestinationMismatchUrlTypeEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDeviceEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum",
    "PositiveGeoTargetTypeEnum",
    "PriceExtensionPriceQualifierEnum",
    "PriceExtensionPriceUnitEnum",
    "PriceExtensionTypeEnum",
    "PricePlaceholderFieldEnum",
    "ProductCategoryLevelEnum",
    "ProductCategoryStateEnum",
    "ProductChannelEnum",
    "ProductChannelExclusivityEnum",
    "ProductConditionEnum",
    "ProductCustomAttributeIndexEnum",
    "ProductLinkInvitationStatusEnum",
    "ProductTypeLevelEnum",
    "PromotionExtensionDiscountModifierEnum",
    "PromotionExtensionOccasionEnum",
    "PromotionPlaceholderFieldEnum",
    "ProximityRadiusUnitsEnum",
    "QualityScoreBucketEnum",
    "ReachPlanAgeRangeEnum",
    "ReachPlanNetworkEnum",
    "ReachPlanSurfaceEnum",
    "RealEstatePlaceholderFieldEnum",
    "RecommendationSubscriptionStatusEnum",
    "RecommendationTypeEnum",
    "ResourceChangeOperationEnum",
    "ResourceLimitTypeEnum",
    "ResponseContentTypeEnum",
    "SearchEngineResultsPageTypeEnum",
    "SearchTermMatchTypeEnum",
    "SearchTermTargetingStatusEnum",
    "SeasonalityEventScopeEnum",
    "SeasonalityEventStatusEnum",
    "ServedAssetFieldTypeEnum",
    "SharedSetStatusEnum",
    "SharedSetTypeEnum",
    "ShoppingAddProductsToCampaignRecommendationEnum",
    "SimulationModificationMethodEnum",
    "SimulationTypeEnum",
    "SitelinkPlaceholderFieldEnum",
    "SkAdNetworkAdEventTypeEnum",
    "SkAdNetworkAttributionCreditEnum",
    "SkAdNetworkCoarseConversionValueEnum",
    "SkAdNetworkSourceTypeEnum",
    "SkAdNetworkUserTypeEnum",
    "SlotEnum",
    "SmartCampaignNotEligibleReasonEnum",
    "SmartCampaignStatusEnum",
    "SpendingLimitTypeEnum",
    "StructuredSnippetPlaceholderFieldEnum",
    "SummaryRowSettingEnum",
    "SystemManagedResourceSourceEnum",
    "TargetCpaOptInRecommendationGoalEnum",
    "TargetFrequencyTimeUnitEnum",
    "TargetImpressionShareLocationEnum",
    "TargetingDimensionEnum",
    "TimeTypeEnum",
    "TrackingCodePageFormatEnum",
    "TrackingCodeTypeEnum",
    "TravelPlaceholderFieldEnum",
    "UserIdentifierSourceEnum",
    "UserInterestTaxonomyTypeEnum",
    "UserListAccessStatusEnum",
    "UserListClosingReasonEnum",
    "UserListCrmDataSourceTypeEnum",
    "UserListDateRuleItemOperatorEnum",
    "UserListFlexibleRuleOperatorEnum",
    "UserListLogicalRuleOperatorEnum",
    "UserListMembershipStatusEnum",
    "UserListNumberRuleItemOperatorEnum",
    "UserListPrepopulationStatusEnum",
    "UserListRuleTypeEnum",
    "UserListSizeRangeEnum",
    "UserListStringRuleItemOperatorEnum",
    "UserListTypeEnum",
    "ValueRuleDeviceTypeEnum",
    "ValueRuleGeoLocationMatchTypeEnum",
    "ValueRuleOperationEnum",
    "ValueRuleSetAttachmentTypeEnum",
    "ValueRuleSetDimensionEnum",
    "VanityPharmaDisplayUrlModeEnum",
    "VanityPharmaTextEnum",
    "VideoThumbnailEnum",
    "WebpageConditionOperandEnum",
    "WebpageConditionOperatorEnum",
]

# Names in __all__ with no definition:
#   AccessInvitationStatusEnum
#   AccessReasonEnum
#   AccessRoleEnum
#   AccountBudgetProposalStatusEnum
#   AccountBudgetProposalTypeEnum
#   AccountBudgetStatusEnum
#   AccountLinkStatusEnum
#   AdCustomizerPlaceholderFieldEnum
#   AdDestinationTypeEnum
#   AdGroupAdPrimaryStatusEnum
#   AdGroupAdPrimaryStatusReasonEnum
#   AdGroupAdRotationModeEnum
#   AdGroupAdStatusEnum
#   AdGroupCriterionApprovalStatusEnum
#   AdGroupCriterionStatusEnum
#   AdGroupPrimaryStatusEnum
#   AdGroupPrimaryStatusReasonEnum
#   AdGroupStatusEnum
#   AdGroupTypeEnum
#   AdNetworkTypeEnum
#   AdServingOptimizationStatusEnum
#   AdStrengthEnum
#   AdTypeEnum
#   AdvertisingChannelSubTypeEnum
#   AdvertisingChannelTypeEnum
#   AffiliateLocationFeedRelationshipTypeEnum
#   AffiliateLocationPlaceholderFieldEnum
#   AgeRangeTypeEnum
#   AndroidPrivacyInteractionTypeEnum
#   AndroidPrivacyNetworkTypeEnum
#   AppBiddingGoalEnum
#   AppCampaignAppStoreEnum
#   AppCampaignBiddingStrategyGoalTypeEnum
#   AppPaymentModelTypeEnum
#   AppPlaceholderFieldEnum
#   AppStoreEnum
#   AppUrlOperatingSystemTypeEnum
#   AssetAutomationStatusEnum
#   AssetAutomationTypeEnum
#   AssetFieldTypeEnum
#   AssetGroupPrimaryStatusEnum
#   AssetGroupPrimaryStatusReasonEnum
#   AssetGroupSignalApprovalStatusEnum
#   AssetGroupStatusEnum
#   AssetLinkPrimaryStatusEnum
#   AssetLinkPrimaryStatusReasonEnum
#   AssetLinkStatusEnum
#   AssetOfflineEvaluationErrorReasonsEnum
#   AssetPerformanceLabelEnum
#   AssetSetAssetStatusEnum
#   AssetSetLinkStatusEnum
#   AssetSetStatusEnum
#   AssetSetTypeEnum
#   AssetSourceEnum
#   AssetTypeEnum
#   AsyncActionStatusEnum
#   AttributionModelEnum
#   AudienceInsightsDimensionEnum
#   AudienceScopeEnum
#   AudienceStatusEnum
#   BatchJobStatusEnum
#   BidModifierSourceEnum
#   BiddingSourceEnum
#   BiddingStrategyStatusEnum
#   BiddingStrategySystemStatusEnum
#   BiddingStrategyTypeEnum
#   BillingSetupStatusEnum
#   BrandRequestRejectionReasonEnum
#   BrandSafetySuitabilityEnum
#   BrandStateEnum
#   BudgetCampaignAssociationStatusEnum
#   BudgetDeliveryMethodEnum
#   BudgetPeriodEnum
#   BudgetStatusEnum
#   BudgetTypeEnum
#   CallConversionReportingStateEnum
#   CallPlaceholderFieldEnum
#   CallToActionTypeEnum
#   CallTrackingDisplayLocationEnum
#   CallTypeEnum
#   CalloutPlaceholderFieldEnum
#   CampaignCriterionStatusEnum
#   CampaignDraftStatusEnum
#   CampaignExperimentTypeEnum
#   CampaignGroupStatusEnum
#   CampaignPrimaryStatusEnum
#   CampaignPrimaryStatusReasonEnum
#   CampaignServingStatusEnum
#   CampaignSharedSetStatusEnum
#   CampaignStatusEnum
#   ChainRelationshipTypeEnum
#   ChangeClientTypeEnum
#   ChangeEventResourceTypeEnum
#   ChangeStatusOperationEnum
#   ChangeStatusResourceTypeEnum
#   ClickTypeEnum
#   CombinedAudienceStatusEnum
#   ConsentStatusEnum
#   ContentLabelTypeEnum
#   ConversionActionCategoryEnum
#   ConversionActionCountingTypeEnum
#   ConversionActionStatusEnum
#   ConversionActionTypeEnum
#   ConversionAdjustmentTypeEnum
#   ConversionAttributionEventTypeEnum
#   ConversionCustomVariableStatusEnum
#   ConversionEnvironmentEnum
#   ConversionLagBucketEnum
#   ConversionOrAdjustmentLagBucketEnum
#   ConversionOriginEnum
#   ConversionTrackingStatusEnum
#   ConversionValueRulePrimaryDimensionEnum
#   ConversionValueRuleSetStatusEnum
#   ConversionValueRuleStatusEnum
#   ConvertingUserPriorEngagementTypeAndLtvBucketEnum
#   CriterionCategoryChannelAvailabilityModeEnum
#   CriterionCategoryLocaleAvailabilityModeEnum
#   CriterionSystemServingStatusEnum
#   CriterionTypeEnum
#   CustomAudienceMemberTypeEnum
#   CustomAudienceStatusEnum
#   CustomAudienceTypeEnum
#   CustomConversionGoalStatusEnum
#   CustomInterestMemberTypeEnum
#   CustomInterestStatusEnum
#   CustomInterestTypeEnum
#   CustomPlaceholderFieldEnum
#   CustomerAcquisitionOptimizationModeEnum
#   CustomerMatchUploadKeyTypeEnum
#   CustomerPayPerConversionEligibilityFailureReasonEnum
#   CustomerStatusEnum
#   CustomizerAttributeStatusEnum
#   CustomizerAttributeTypeEnum
#   CustomizerValueStatusEnum
#   DataDrivenModelStatusEnum
#   DayOfWeekEnum
#   DeviceEnum
#   DisplayAdFormatSettingEnum
#   DisplayUploadProductTypeEnum
#   DistanceBucketEnum
#   DsaPageFeedCriterionFieldEnum
#   EducationPlaceholderFieldEnum
#   ExperimentMetricDirectionEnum
#   ExperimentMetricEnum
#   ExperimentStatusEnum
#   ExperimentTypeEnum
#   ExtensionSettingDeviceEnum
#   ExtensionTypeEnum
#   ExternalConversionSourceEnum
#   FeedAttributeTypeEnum
#   FeedItemQualityApprovalStatusEnum
#   FeedItemQualityDisapprovalReasonEnum
#   FeedItemSetStatusEnum
#   FeedItemSetStringFilterTypeEnum
#   FeedItemStatusEnum
#   FeedItemTargetDeviceEnum
#   FeedItemTargetStatusEnum
#   FeedItemTargetTypeEnum
#   FeedItemValidationStatusEnum
#   FeedLinkStatusEnum
#   FeedMappingCriterionTypeEnum
#   FeedMappingStatusEnum
#   FeedOriginEnum
#   FeedStatusEnum
#   FlightPlaceholderFieldEnum
#   FrequencyCapEventTypeEnum
#   FrequencyCapLevelEnum
#   FrequencyCapTimeUnitEnum
#   GenderTypeEnum
#   GeoTargetConstantStatusEnum
#   GeoTargetingRestrictionEnum
#   GeoTargetingTypeEnum
#   GoalConfigLevelEnum
#   GoogleAdsFieldCategoryEnum
#   GoogleAdsFieldDataTypeEnum
#   GoogleVoiceCallStatusEnum
#   HotelAssetSuggestionStatusEnum
#   HotelDateSelectionTypeEnum
#   HotelPlaceholderFieldEnum
#   HotelPriceBucketEnum
#   HotelRateTypeEnum
#   HotelReconciliationStatusEnum
#   IdentityVerificationProgramEnum
#   IdentityVerificationProgramStatusEnum
#   ImagePlaceholderFieldEnum
#   IncomeRangeTypeEnum
#   InteractionEventTypeEnum
#   InteractionTypeEnum
#   InvoiceTypeEnum
#   JobPlaceholderFieldEnum
#   KeywordMatchTypeEnum
#   KeywordPlanAggregateMetricTypeEnum
#   KeywordPlanCompetitionLevelEnum
#   KeywordPlanConceptGroupTypeEnum
#   KeywordPlanForecastIntervalEnum
#   KeywordPlanKeywordAnnotationEnum
#   KeywordPlanNetworkEnum
#   LabelStatusEnum
#   LeadFormCallToActionTypeEnum
#   LeadFormDesiredIntentEnum
#   LeadFormFieldUserInputTypeEnum
#   LeadFormPostSubmitCallToActionTypeEnum
#   LegacyAppInstallAdAppStoreEnum
#   LinkedAccountTypeEnum
#   LinkedProductTypeEnum
#   ListingGroupFilterCustomAttributeIndexEnum
#   ListingGroupFilterListingSourceEnum
#   ListingGroupFilterProductCategoryLevelEnum
#   ListingGroupFilterProductChannelEnum
#   ListingGroupFilterProductConditionEnum
#   ListingGroupFilterProductTypeLevelEnum
#   ListingGroupFilterTypeEnum
#   ListingGroupTypeEnum
#   ListingTypeEnum
#   LocalPlaceholderFieldEnum
#   LocalServicesBusinessRegistrationCheckRejectionReasonEnum
#   LocalServicesBusinessRegistrationTypeEnum
#   LocalServicesCreditStateEnum
#   LocalServicesEmployeeStatusEnum
#   LocalServicesEmployeeTypeEnum
#   LocalServicesInsuranceRejectionReasonEnum
#   LocalServicesLeadConversationTypeEnum
#   LocalServicesLeadStatusEnum
#   LocalServicesLeadTypeEnum
#   LocalServicesLicenseRejectionReasonEnum
#   LocalServicesParticipantTypeEnum
#   LocalServicesVerificationArtifactStatusEnum
#   LocalServicesVerificationArtifactTypeEnum
#   LocalServicesVerificationStatusEnum
#   LocationExtensionTargetingCriterionFieldEnum
#   LocationGroupRadiusUnitsEnum
#   LocationOwnershipTypeEnum
#   LocationPlaceholderFieldEnum
#   LocationSourceTypeEnum
#   LocationStringFilterTypeEnum
#   LookalikeExpansionLevelEnum
#   ManagerLinkStatusEnum
#   MatchingFunctionContextTypeEnum
#   MatchingFunctionOperatorEnum
#   MediaTypeEnum
#   MessagePlaceholderFieldEnum
#   MimeTypeEnum
#   MinuteOfHourEnum
#   MobileAppVendorEnum
#   MobileDeviceTypeEnum
#   MonthOfYearEnum
#   NegativeGeoTargetTypeEnum
#   OfflineConversionDiagnosticStatusEnum
#   OfflineEventUploadClientEnum
#   OfflineUserDataJobFailureReasonEnum
#   OfflineUserDataJobMatchRateRangeEnum
#   OfflineUserDataJobStatusEnum
#   OfflineUserDataJobTypeEnum
#   OperatingSystemVersionOperatorTypeEnum
#   OptimizationGoalTypeEnum
#   ParentalStatusTypeEnum
#   PaymentModeEnum
#   PerformanceMaxUpgradeStatusEnum
#   PlaceholderTypeEnum
#   PlacementTypeEnum
#   PolicyApprovalStatusEnum
#   PolicyReviewStatusEnum
#   PolicyTopicEntryTypeEnum
#   PolicyTopicEvidenceDestinationMismatchUrlTypeEnum
#   PolicyTopicEvidenceDestinationNotWorkingDeviceEnum
#   PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum
#   PositiveGeoTargetTypeEnum
#   PriceExtensionPriceQualifierEnum
#   PriceExtensionPriceUnitEnum
#   PriceExtensionTypeEnum
#   PricePlaceholderFieldEnum
#   ProductCategoryLevelEnum
#   ProductCategoryStateEnum
#   ProductChannelEnum
#   ProductChannelExclusivityEnum
#   ProductConditionEnum
#   ProductCustomAttributeIndexEnum
#   ProductLinkInvitationStatusEnum
#   ProductTypeLevelEnum
#   PromotionExtensionDiscountModifierEnum
#   PromotionExtensionOccasionEnum
#   PromotionPlaceholderFieldEnum
#   ProximityRadiusUnitsEnum
#   QualityScoreBucketEnum
#   ReachPlanAgeRangeEnum
#   ReachPlanNetworkEnum
#   ReachPlanSurfaceEnum
#   RealEstatePlaceholderFieldEnum
#   RecommendationSubscriptionStatusEnum
#   RecommendationTypeEnum
#   ResourceChangeOperationEnum
#   ResourceLimitTypeEnum
#   ResponseContentTypeEnum
#   SearchEngineResultsPageTypeEnum
#   SearchTermMatchTypeEnum
#   SearchTermTargetingStatusEnum
#   SeasonalityEventScopeEnum
#   SeasonalityEventStatusEnum
#   ServedAssetFieldTypeEnum
#   SharedSetStatusEnum
#   SharedSetTypeEnum
#   ShoppingAddProductsToCampaignRecommendationEnum
#   SimulationModificationMethodEnum
#   SimulationTypeEnum
#   SitelinkPlaceholderFieldEnum
#   SkAdNetworkAdEventTypeEnum
#   SkAdNetworkAttributionCreditEnum
#   SkAdNetworkCoarseConversionValueEnum
#   SkAdNetworkSourceTypeEnum
#   SkAdNetworkUserTypeEnum
#   SlotEnum
#   SmartCampaignNotEligibleReasonEnum
#   SmartCampaignStatusEnum
#   SpendingLimitTypeEnum
#   StructuredSnippetPlaceholderFieldEnum
#   SummaryRowSettingEnum
#   SystemManagedResourceSourceEnum
#   TargetCpaOptInRecommendationGoalEnum
#   TargetFrequencyTimeUnitEnum
#   TargetImpressionShareLocationEnum
#   TargetingDimensionEnum
#   TimeTypeEnum
#   TrackingCodePageFormatEnum
#   TrackingCodeTypeEnum
#   TravelPlaceholderFieldEnum
#   UserIdentifierSourceEnum
#   UserInterestTaxonomyTypeEnum
#   UserListAccessStatusEnum
#   UserListClosingReasonEnum
#   UserListCrmDataSourceTypeEnum
#   UserListDateRuleItemOperatorEnum
#   UserListFlexibleRuleOperatorEnum
#   UserListLogicalRuleOperatorEnum
#   UserListMembershipStatusEnum
#   UserListNumberRuleItemOperatorEnum
#   UserListPrepopulationStatusEnum
#   UserListRuleTypeEnum
#   UserListSizeRangeEnum
#   UserListStringRuleItemOperatorEnum
#   UserListTypeEnum
#   ValueRuleDeviceTypeEnum
#   ValueRuleGeoLocationMatchTypeEnum
#   ValueRuleOperationEnum
#   ValueRuleSetAttachmentTypeEnum
#   ValueRuleSetDimensionEnum
#   VanityPharmaDisplayUrlModeEnum
#   VanityPharmaTextEnum
#   VideoThumbnailEnum
#   WebpageConditionOperandEnum
#   WebpageConditionOperatorEnum



from .base import (
    OfflineUserDataJobServiceTransport as OfflineUserDataJobServiceTransport,
)
from .grpc import (
    OfflineUserDataJobServiceGrpcTransport as OfflineUserDataJobServiceGrpcTransport,
)

__all__ = [
    "OfflineUserDataJobServiceTransport",
    "OfflineUserDataJobServiceGrpcTransport",
]



from .base import RemarketingActionServiceTransport as RemarketingActionServiceTransport
from .grpc import (
    RemarketingActionServiceGrpcTransport as RemarketingActionServiceGrpcTransport,
)

__all__ = ["RemarketingActionServiceTransport", "RemarketingActionServiceGrpcTransport"]



from .base import GoogleAdsFieldServiceTransport as GoogleAdsFieldServiceTransport
from .grpc import (
    GoogleAdsFieldServiceGrpcTransport as GoogleAdsFieldServiceGrpcTransport,
)

__all__ = ["GoogleAdsFieldServiceTransport", "GoogleAdsFieldServiceGrpcTransport"]



from .base import GoogleAdsServiceTransport as GoogleAdsServiceTransport
from .grpc import GoogleAdsServiceGrpcTransport as GoogleAdsServiceGrpcTransport

__all__ = ["GoogleAdsServiceTransport", "GoogleAdsServiceGrpcTransport"]



from .base import (
    ConversionGoalCampaignConfigServiceTransport as ConversionGoalCampaignConfigServiceTransport,
)
from .grpc import (
    ConversionGoalCampaignConfigServiceGrpcTransport as ConversionGoalCampaignConfigServiceGrpcTransport,
)

__all__ = [
    "ConversionGoalCampaignConfigServiceTransport",
    "ConversionGoalCampaignConfigServiceGrpcTransport",
]



from .base import ExperimentArmServiceTransport as ExperimentArmServiceTransport
from .grpc import ExperimentArmServiceGrpcTransport as ExperimentArmServiceGrpcTransport

__all__ = ["ExperimentArmServiceTransport", "ExperimentArmServiceGrpcTransport"]



from .base import InvoiceServiceTransport as InvoiceServiceTransport
from .grpc import InvoiceServiceGrpcTransport as InvoiceServiceGrpcTransport

__all__ = ["InvoiceServiceTransport", "InvoiceServiceGrpcTransport"]



import abc
from typing import Awaitable, Callable, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v17.services.types import keyword_plan_idea_service

__all__ = ["KeywordPlanIdeaServiceTransport"]

class KeywordPlanIdeaServiceTransport(abc.ABC):
    AUTH_SCOPES: Incomplete
    DEFAULT_HOST: str
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
        **kwargs,
    ) -> None: ...
    def close(self) -> None: ...
    @property
    def generate_keyword_ideas(
        self,
    ) -> Callable[
        [keyword_plan_idea_service.GenerateKeywordIdeasRequest],
        keyword_plan_idea_service.GenerateKeywordIdeaResponse
        | Awaitable[keyword_plan_idea_service.GenerateKeywordIdeaResponse],
    ]: ...
    @property
    def generate_keyword_historical_metrics(
        self,
    ) -> Callable[
        [keyword_plan_idea_service.GenerateKeywordHistoricalMetricsRequest],
        keyword_plan_idea_service.GenerateKeywordHistoricalMetricsResponse
        | Awaitable[keyword_plan_idea_service.GenerateKeywordHistoricalMetricsResponse],
    ]: ...
    @property
    def generate_ad_group_themes(
        self,
    ) -> Callable[
        [keyword_plan_idea_service.GenerateAdGroupThemesRequest],
        keyword_plan_idea_service.GenerateAdGroupThemesResponse
        | Awaitable[keyword_plan_idea_service.GenerateAdGroupThemesResponse],
    ]: ...
    @property
    def generate_keyword_forecast_metrics(
        self,
    ) -> Callable[
        [keyword_plan_idea_service.GenerateKeywordForecastMetricsRequest],
        keyword_plan_idea_service.GenerateKeywordForecastMetricsResponse
        | Awaitable[keyword_plan_idea_service.GenerateKeywordForecastMetricsResponse],
    ]: ...



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.common.types.ad_type_infos import SmartCampaignAdInfo
from google.ads.googleads.v17.common.types.criteria import (
    AdScheduleInfo,
    KeywordThemeInfo,
    LocationInfo,
    ProximityInfo,
)
from google.ads.googleads.v17.resources.types.keyword_theme_constant import (
    KeywordThemeConstant,
)

_M = TypeVar("_M")

class SmartCampaignSuggestionInfo(proto.Message):
    class BusinessContext(proto.Message):
        business_name: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            business_name: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["business_name"]
        ) -> bool: ...

    class LocationList(proto.Message):
        locations: MutableSequence[LocationInfo]
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            locations: MutableSequence[LocationInfo] = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["locations"]
        ) -> bool: ...

    final_url: str
    language_code: str
    ad_schedules: MutableSequence[AdScheduleInfo]
    keyword_themes: MutableSequence[KeywordThemeInfo]
    business_context: SmartCampaignSuggestionInfo.BusinessContext
    business_profile_location: str
    location_list: SmartCampaignSuggestionInfo.LocationList
    proximity: ProximityInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        final_url: str = ...,
        language_code: str = ...,
        ad_schedules: MutableSequence[AdScheduleInfo] = ...,
        keyword_themes: MutableSequence[KeywordThemeInfo] = ...,
        business_context: SmartCampaignSuggestionInfo.BusinessContext = ...,
        business_profile_location: str = ...,
        location_list: SmartCampaignSuggestionInfo.LocationList = ...,
        proximity: ProximityInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "final_url",
            "language_code",
            "ad_schedules",
            "keyword_themes",
            "business_context",
            "business_profile_location",
            "location_list",
            "proximity",
        ],
    ) -> bool: ...

class SuggestKeywordThemesRequest(proto.Message):
    customer_id: str
    suggestion_info: SmartCampaignSuggestionInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        suggestion_info: SmartCampaignSuggestionInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "suggestion_info"]
    ) -> bool: ...

class SuggestKeywordThemesResponse(proto.Message):
    class KeywordTheme(proto.Message):
        keyword_theme_constant: KeywordThemeConstant
        free_form_keyword_theme: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            keyword_theme_constant: KeywordThemeConstant = ...,
            free_form_keyword_theme: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["keyword_theme_constant", "free_form_keyword_theme"]
        ) -> bool: ...

    keyword_themes: MutableSequence[SuggestKeywordThemesResponse.KeywordTheme]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        keyword_themes: MutableSequence[
            SuggestKeywordThemesResponse.KeywordTheme
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["keyword_themes"]
    ) -> bool: ...

class SuggestSmartCampaignAdRequest(proto.Message):
    customer_id: str
    suggestion_info: SmartCampaignSuggestionInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        suggestion_info: SmartCampaignSuggestionInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "suggestion_info"]
    ) -> bool: ...

class SuggestSmartCampaignAdResponse(proto.Message):
    ad_info: SmartCampaignAdInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        ad_info: SmartCampaignAdInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["ad_info"]
    ) -> bool: ...

class SuggestSmartCampaignBudgetOptionsRequest(proto.Message):
    customer_id: str
    campaign: str
    suggestion_info: SmartCampaignSuggestionInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        campaign: str = ...,
        suggestion_info: SmartCampaignSuggestionInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "campaign", "suggestion_info"]
    ) -> bool: ...

class SuggestSmartCampaignBudgetOptionsResponse(proto.Message):
    class BudgetOption(proto.Message):
        daily_amount_micros: int
        metrics: SuggestSmartCampaignBudgetOptionsResponse.Metrics
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            daily_amount_micros: int = ...,
            metrics: SuggestSmartCampaignBudgetOptionsResponse.Metrics = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["daily_amount_micros", "metrics"]
        ) -> bool: ...

    class Metrics(proto.Message):
        min_daily_clicks: int
        max_daily_clicks: int
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            min_daily_clicks: int = ...,
            max_daily_clicks: int = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["min_daily_clicks", "max_daily_clicks"]
        ) -> bool: ...

    low: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption
    recommended: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption
    high: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        low: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption = ...,
        recommended: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption = ...,
        high: SuggestSmartCampaignBudgetOptionsResponse.BudgetOption = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["low", "recommended", "high"]
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class AdGroupAdPrimaryStatusReasonEnum(proto.Message):
    class AdGroupAdPrimaryStatusReason(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        CAMPAIGN_REMOVED = 2
        CAMPAIGN_PAUSED = 3
        CAMPAIGN_PENDING = 4
        CAMPAIGN_ENDED = 5
        AD_GROUP_PAUSED = 6
        AD_GROUP_REMOVED = 7
        AD_GROUP_AD_PAUSED = 8
        AD_GROUP_AD_REMOVED = 9
        AD_GROUP_AD_DISAPPROVED = 10
        AD_GROUP_AD_UNDER_REVIEW = 11
        AD_GROUP_AD_POOR_QUALITY = 12
        AD_GROUP_AD_NO_ADS = 13
        AD_GROUP_AD_APPROVED_LABELED = 14
        AD_GROUP_AD_AREA_OF_INTEREST_ONLY = 15
        AD_GROUP_AD_UNDER_APPEAL = 16

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .base import ExperimentServiceTransport as ExperimentServiceTransport
from .grpc import ExperimentServiceGrpcTransport as ExperimentServiceGrpcTransport

__all__ = ["ExperimentServiceTransport", "ExperimentServiceGrpcTransport"]



from .base import AdGroupCustomizerServiceTransport as AdGroupCustomizerServiceTransport
from .grpc import (
    AdGroupCustomizerServiceGrpcTransport as AdGroupCustomizerServiceGrpcTransport,
)

__all__ = ["AdGroupCustomizerServiceTransport", "AdGroupCustomizerServiceGrpcTransport"]



from .base import FeedItemSetServiceTransport as FeedItemSetServiceTransport
from .grpc import FeedItemSetServiceGrpcTransport as FeedItemSetServiceGrpcTransport

__all__ = ["FeedItemSetServiceTransport", "FeedItemSetServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.feed_item_set_string_filter_type import (
    FeedItemSetStringFilterTypeEnum,
)

_M = TypeVar("_M")

class BusinessNameFilter(proto.Message):
    business_name: str
    filter_type: FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        business_name: str = ...,
        filter_type: FeedItemSetStringFilterTypeEnum.FeedItemSetStringFilterType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["business_name", "filter_type"]
    ) -> bool: ...

class DynamicAffiliateLocationSetFilter(proto.Message):
    chain_ids: MutableSequence[int]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        chain_ids: MutableSequence[int] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["chain_ids"]
    ) -> bool: ...

class DynamicLocationSetFilter(proto.Message):
    labels: MutableSequence[str]
    business_name_filter: BusinessNameFilter
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        labels: MutableSequence[str] = ...,
        business_name_filter: BusinessNameFilter = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["labels", "business_name_filter"]
    ) -> bool: ...



from .base import AssetGroupSignalServiceTransport as AssetGroupSignalServiceTransport
from .grpc import (
    AssetGroupSignalServiceGrpcTransport as AssetGroupSignalServiceGrpcTransport,
)

__all__ = ["AssetGroupSignalServiceTransport", "AssetGroupSignalServiceGrpcTransport"]



from .base import (
    CustomerExtensionSettingServiceTransport as CustomerExtensionSettingServiceTransport,
)
from .grpc import (
    CustomerExtensionSettingServiceGrpcTransport as CustomerExtensionSettingServiceGrpcTransport,
)

__all__ = [
    "CustomerExtensionSettingServiceTransport",
    "CustomerExtensionSettingServiceGrpcTransport",
]



from .base import (
    CustomerCustomizerServiceTransport as CustomerCustomizerServiceTransport,
)
from .grpc import (
    CustomerCustomizerServiceGrpcTransport as CustomerCustomizerServiceGrpcTransport,
)

__all__ = [
    "CustomerCustomizerServiceTransport",
    "CustomerCustomizerServiceGrpcTransport",
]



from .base import BiddingStrategyServiceTransport as BiddingStrategyServiceTransport
from .grpc import (
    BiddingStrategyServiceGrpcTransport as BiddingStrategyServiceGrpcTransport,
)

__all__ = ["BiddingStrategyServiceTransport", "BiddingStrategyServiceGrpcTransport"]



import grpc

from google.ads.googleads.v16 import GoogleAdsFailure as GoogleAdsFailureV16
from google.ads.googleads.v17 import GoogleAdsFailure as GoogleAdsFailureV17

GoogleAdsFailure = GoogleAdsFailureV16 | GoogleAdsFailureV17

class GoogleAdsException(Exception):
    error: grpc.RpcError = ...
    call: grpc.Call = ...
    failure: GoogleAdsFailure = ...
    request_id: str = ...
    def __init__(
        self,
        error: grpc.RpcError,
        call: grpc.Call,
        failure: GoogleAdsFailure,
        request_id: str,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.common.types.criteria import (
    BrandInfo,
    KeywordInfo,
    MobileAppCategoryInfo,
    MobileApplicationInfo,
    PlacementInfo,
    YouTubeChannelInfo,
    YouTubeVideoInfo,
)
from google.ads.googleads.v16.enums.types.criterion_type import CriterionTypeEnum

_M = TypeVar("_M")

class SharedCriterion(proto.Message):
    resource_name: str
    shared_set: str
    criterion_id: int
    type_: CriterionTypeEnum.CriterionType
    keyword: KeywordInfo
    youtube_video: YouTubeVideoInfo
    youtube_channel: YouTubeChannelInfo
    placement: PlacementInfo
    mobile_app_category: MobileAppCategoryInfo
    mobile_application: MobileApplicationInfo
    brand: BrandInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        shared_set: str = ...,
        criterion_id: int = ...,
        type_: CriterionTypeEnum.CriterionType = ...,
        keyword: KeywordInfo = ...,
        youtube_video: YouTubeVideoInfo = ...,
        youtube_channel: YouTubeChannelInfo = ...,
        placement: PlacementInfo = ...,
        mobile_app_category: MobileAppCategoryInfo = ...,
        mobile_application: MobileApplicationInfo = ...,
        brand: BrandInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "shared_set",
            "criterion_id",
            "type_",
            "keyword",
            "youtube_video",
            "youtube_channel",
            "placement",
            "mobile_app_category",
            "mobile_application",
            "brand",
        ],
    ) -> bool: ...



from .base import CampaignAssetServiceTransport as CampaignAssetServiceTransport
from .grpc import CampaignAssetServiceGrpcTransport as CampaignAssetServiceGrpcTransport

__all__ = ["CampaignAssetServiceTransport", "CampaignAssetServiceGrpcTransport"]



from .base import ProductLinkServiceTransport as ProductLinkServiceTransport
from .grpc import ProductLinkServiceGrpcTransport as ProductLinkServiceGrpcTransport

__all__ = ["ProductLinkServiceTransport", "ProductLinkServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.common.types.local_services import (
    LocalServicesDocumentReadOnly,
)
from google.ads.googleads.v16.enums.types.local_services_business_registration_check_rejection_reason import (
    LocalServicesBusinessRegistrationCheckRejectionReasonEnum,
)
from google.ads.googleads.v16.enums.types.local_services_business_registration_type import (
    LocalServicesBusinessRegistrationTypeEnum,
)
from google.ads.googleads.v16.enums.types.local_services_insurance_rejection_reason import (
    LocalServicesInsuranceRejectionReasonEnum,
)
from google.ads.googleads.v16.enums.types.local_services_license_rejection_reason import (
    LocalServicesLicenseRejectionReasonEnum,
)
from google.ads.googleads.v16.enums.types.local_services_verification_artifact_status import (
    LocalServicesVerificationArtifactStatusEnum,
)
from google.ads.googleads.v16.enums.types.local_services_verification_artifact_type import (
    LocalServicesVerificationArtifactTypeEnum,
)

_M = TypeVar("_M")

class BackgroundCheckVerificationArtifact(proto.Message):
    case_url: str
    final_adjudication_date_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        case_url: str = ...,
        final_adjudication_date_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["case_url", "final_adjudication_date_time"]
    ) -> bool: ...

class BusinessRegistrationCheckVerificationArtifact(proto.Message):
    registration_type: (
        LocalServicesBusinessRegistrationTypeEnum.LocalServicesBusinessRegistrationType
    )
    check_id: str
    rejection_reason: LocalServicesBusinessRegistrationCheckRejectionReasonEnum.LocalServicesBusinessRegistrationCheckRejectionReason
    registration_number: BusinessRegistrationNumber
    registration_document: BusinessRegistrationDocument
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        registration_type: LocalServicesBusinessRegistrationTypeEnum.LocalServicesBusinessRegistrationType = ...,
        check_id: str = ...,
        rejection_reason: LocalServicesBusinessRegistrationCheckRejectionReasonEnum.LocalServicesBusinessRegistrationCheckRejectionReason = ...,
        registration_number: BusinessRegistrationNumber = ...,
        registration_document: BusinessRegistrationDocument = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "registration_type",
            "check_id",
            "rejection_reason",
            "registration_number",
            "registration_document",
        ],
    ) -> bool: ...

class BusinessRegistrationDocument(proto.Message):
    document_readonly: LocalServicesDocumentReadOnly
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        document_readonly: LocalServicesDocumentReadOnly = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["document_readonly"]
    ) -> bool: ...

class BusinessRegistrationNumber(proto.Message):
    number: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        number: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["number"]
    ) -> bool: ...

class InsuranceVerificationArtifact(proto.Message):
    amount_micros: int
    rejection_reason: (
        LocalServicesInsuranceRejectionReasonEnum.LocalServicesInsuranceRejectionReason
    )
    insurance_document_readonly: LocalServicesDocumentReadOnly
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        amount_micros: int = ...,
        rejection_reason: LocalServicesInsuranceRejectionReasonEnum.LocalServicesInsuranceRejectionReason = ...,
        insurance_document_readonly: LocalServicesDocumentReadOnly = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "amount_micros", "rejection_reason", "insurance_document_readonly"
        ],
    ) -> bool: ...

class LicenseVerificationArtifact(proto.Message):
    license_type: str
    license_number: str
    licensee_first_name: str
    licensee_last_name: str
    rejection_reason: (
        LocalServicesLicenseRejectionReasonEnum.LocalServicesLicenseRejectionReason
    )
    license_document_readonly: LocalServicesDocumentReadOnly
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        license_type: str = ...,
        license_number: str = ...,
        licensee_first_name: str = ...,
        licensee_last_name: str = ...,
        rejection_reason: LocalServicesLicenseRejectionReasonEnum.LocalServicesLicenseRejectionReason = ...,
        license_document_readonly: LocalServicesDocumentReadOnly = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "license_type",
            "license_number",
            "licensee_first_name",
            "licensee_last_name",
            "rejection_reason",
            "license_document_readonly",
        ],
    ) -> bool: ...

class LocalServicesVerificationArtifact(proto.Message):
    resource_name: str
    id: int
    creation_date_time: str
    status: LocalServicesVerificationArtifactStatusEnum.LocalServicesVerificationArtifactStatus
    artifact_type: (
        LocalServicesVerificationArtifactTypeEnum.LocalServicesVerificationArtifactType
    )
    background_check_verification_artifact: BackgroundCheckVerificationArtifact
    insurance_verification_artifact: InsuranceVerificationArtifact
    license_verification_artifact: LicenseVerificationArtifact
    business_registration_check_verification_artifact: (
        BusinessRegistrationCheckVerificationArtifact
    )
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        id: int = ...,
        creation_date_time: str = ...,
        status: LocalServicesVerificationArtifactStatusEnum.LocalServicesVerificationArtifactStatus = ...,
        artifact_type: LocalServicesVerificationArtifactTypeEnum.LocalServicesVerificationArtifactType = ...,
        background_check_verification_artifact: BackgroundCheckVerificationArtifact = ...,
        insurance_verification_artifact: InsuranceVerificationArtifact = ...,
        license_verification_artifact: LicenseVerificationArtifact = ...,
        business_registration_check_verification_artifact: BusinessRegistrationCheckVerificationArtifact = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "id",
            "creation_date_time",
            "status",
            "artifact_type",
            "background_check_verification_artifact",
            "insurance_verification_artifact",
            "license_verification_artifact",
            "business_registration_check_verification_artifact",
        ],
    ) -> bool: ...



from .base import ConversionActionServiceTransport as ConversionActionServiceTransport
from .grpc import (
    ConversionActionServiceGrpcTransport as ConversionActionServiceGrpcTransport,
)

__all__ = ["ConversionActionServiceTransport", "ConversionActionServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v16.enums.types.product_link_invitation_status import (
    ProductLinkInvitationStatusEnum,
)
from google.ads.googleads.v16.resources.types.product_link_invitation import (
    ProductLinkInvitation,
)

_M = TypeVar("_M")

class CreateProductLinkInvitationRequest(proto.Message):
    customer_id: str
    product_link_invitation: ProductLinkInvitation
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        product_link_invitation: ProductLinkInvitation = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "product_link_invitation"]
    ) -> bool: ...

class CreateProductLinkInvitationResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class RemoveProductLinkInvitationRequest(proto.Message):
    customer_id: str
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "resource_name"]
    ) -> bool: ...

class RemoveProductLinkInvitationResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class UpdateProductLinkInvitationRequest(proto.Message):
    customer_id: str
    product_link_invitation_status: (
        ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus
    )
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        product_link_invitation_status: ProductLinkInvitationStatusEnum.ProductLinkInvitationStatus = ...,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["customer_id", "product_link_invitation_status", "resource_name"],
    ) -> bool: ...

class UpdateProductLinkInvitationResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...



from .base import CampaignDraftServiceTransport as CampaignDraftServiceTransport
from .grpc import CampaignDraftServiceGrpcTransport as CampaignDraftServiceGrpcTransport

__all__ = ["CampaignDraftServiceTransport", "CampaignDraftServiceGrpcTransport"]



from .base import BatchJobServiceTransport as BatchJobServiceTransport
from .grpc import BatchJobServiceGrpcTransport as BatchJobServiceGrpcTransport

__all__ = ["BatchJobServiceTransport", "BatchJobServiceGrpcTransport"]



from .base import AssetGroupAssetServiceTransport as AssetGroupAssetServiceTransport
from .grpc import (
    AssetGroupAssetServiceGrpcTransport as AssetGroupAssetServiceGrpcTransport,
)

__all__ = ["AssetGroupAssetServiceTransport", "AssetGroupAssetServiceGrpcTransport"]



from .base import AssetSetServiceTransport as AssetSetServiceTransport
from .grpc import AssetSetServiceGrpcTransport as AssetSetServiceGrpcTransport

__all__ = ["AssetSetServiceTransport", "AssetSetServiceGrpcTransport"]



from .base import CampaignCriterionServiceTransport as CampaignCriterionServiceTransport
from .grpc import (
    CampaignCriterionServiceGrpcTransport as CampaignCriterionServiceGrpcTransport,
)

__all__ = ["CampaignCriterionServiceTransport", "CampaignCriterionServiceGrpcTransport"]



from .base import LabelServiceTransport as LabelServiceTransport
from .grpc import LabelServiceGrpcTransport as LabelServiceGrpcTransport

__all__ = ["LabelServiceTransport", "LabelServiceGrpcTransport"]



from .base import AdGroupCriterionServiceTransport as AdGroupCriterionServiceTransport
from .grpc import (
    AdGroupCriterionServiceGrpcTransport as AdGroupCriterionServiceGrpcTransport,
)

__all__ = ["AdGroupCriterionServiceTransport", "AdGroupCriterionServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class ConversionGoalCampaignConfigErrorEnum(proto.Message):
    class ConversionGoalCampaignConfigError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        CANNOT_USE_CAMPAIGN_GOAL_FOR_SEARCH_ADS_360_MANAGED_CAMPAIGN = 2
        CUSTOM_GOAL_DOES_NOT_BELONG_TO_GOOGLE_ADS_CONVERSION_CUSTOMER = 3
        CAMPAIGN_CANNOT_USE_UNIFIED_GOALS = 4
        EMPTY_CONVERSION_GOALS = 5
        STORE_SALE_STORE_VISIT_CANNOT_BE_BOTH_INCLUDED = 6
        PERFORMANCE_MAX_CAMPAIGN_CANNOT_USE_CUSTOM_GOAL_WITH_STORE_SALES = 7

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .base import LocalServicesLeadServiceTransport as LocalServicesLeadServiceTransport
from .grpc import (
    LocalServicesLeadServiceGrpcTransport as LocalServicesLeadServiceGrpcTransport,
)

__all__ = ["LocalServicesLeadServiceTransport", "LocalServicesLeadServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.product_category_level import (
    ProductCategoryLevelEnum,
)
from google.ads.googleads.v17.enums.types.product_category_state import (
    ProductCategoryStateEnum,
)

_M = TypeVar("_M")

class ProductCategoryConstant(proto.Message):
    class ProductCategoryLocalization(proto.Message):
        region_code: str
        language_code: str
        value: str
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            region_code: str = ...,
            language_code: str = ...,
            value: str = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["region_code", "language_code", "value"]
        ) -> bool: ...

    resource_name: str
    category_id: int
    product_category_constant_parent: str
    level: ProductCategoryLevelEnum.ProductCategoryLevel
    state: ProductCategoryStateEnum.ProductCategoryState
    localizations: MutableSequence[ProductCategoryConstant.ProductCategoryLocalization]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        category_id: int = ...,
        product_category_constant_parent: str = ...,
        level: ProductCategoryLevelEnum.ProductCategoryLevel = ...,
        state: ProductCategoryStateEnum.ProductCategoryState = ...,
        localizations: MutableSequence[
            ProductCategoryConstant.ProductCategoryLocalization
        ] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "category_id",
            "product_category_constant_parent",
            "level",
            "state",
            "localizations",
        ],
    ) -> bool: ...



from .base import GeoTargetConstantServiceTransport as GeoTargetConstantServiceTransport
from .grpc import (
    GeoTargetConstantServiceGrpcTransport as GeoTargetConstantServiceGrpcTransport,
)

__all__ = ["GeoTargetConstantServiceTransport", "GeoTargetConstantServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.identity_verification_program import (
    IdentityVerificationProgramEnum,
)
from google.ads.googleads.v17.enums.types.identity_verification_program_status import (
    IdentityVerificationProgramStatusEnum,
)

_M = TypeVar("_M")

class GetIdentityVerificationRequest(proto.Message):
    customer_id: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id"]
    ) -> bool: ...

class GetIdentityVerificationResponse(proto.Message):
    identity_verification: MutableSequence[IdentityVerification]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        identity_verification: MutableSequence[IdentityVerification] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["identity_verification"]
    ) -> bool: ...

class IdentityVerification(proto.Message):
    verification_program: IdentityVerificationProgramEnum.IdentityVerificationProgram
    identity_verification_requirement: IdentityVerificationRequirement
    verification_progress: IdentityVerificationProgress
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        verification_program: IdentityVerificationProgramEnum.IdentityVerificationProgram = ...,
        identity_verification_requirement: IdentityVerificationRequirement = ...,
        verification_progress: IdentityVerificationProgress = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "verification_program",
            "identity_verification_requirement",
            "verification_progress",
        ],
    ) -> bool: ...

class IdentityVerificationProgress(proto.Message):
    program_status: (
        IdentityVerificationProgramStatusEnum.IdentityVerificationProgramStatus
    )
    invitation_link_expiration_time: str
    action_url: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        program_status: IdentityVerificationProgramStatusEnum.IdentityVerificationProgramStatus = ...,
        invitation_link_expiration_time: str = ...,
        action_url: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["program_status", "invitation_link_expiration_time", "action_url"],
    ) -> bool: ...

class IdentityVerificationRequirement(proto.Message):
    verification_start_deadline_time: str
    verification_completion_deadline_time: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        verification_start_deadline_time: str = ...,
        verification_completion_deadline_time: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "verification_start_deadline_time", "verification_completion_deadline_time"
        ],
    ) -> bool: ...

class StartIdentityVerificationRequest(proto.Message):
    customer_id: str
    verification_program: IdentityVerificationProgramEnum.IdentityVerificationProgram
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        verification_program: IdentityVerificationProgramEnum.IdentityVerificationProgram = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "verification_program"]
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.experiment_metric import ExperimentMetricEnum
from google.ads.googleads.v17.enums.types.experiment_metric_direction import (
    ExperimentMetricDirectionEnum,
)

_M = TypeVar("_M")

class MetricGoal(proto.Message):
    metric: ExperimentMetricEnum.ExperimentMetric
    direction: ExperimentMetricDirectionEnum.ExperimentMetricDirection
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        metric: ExperimentMetricEnum.ExperimentMetric = ...,
        direction: ExperimentMetricDirectionEnum.ExperimentMetricDirection = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["metric", "direction"]
    ) -> bool: ...



from .base import CampaignLabelServiceTransport as CampaignLabelServiceTransport
from .grpc import CampaignLabelServiceGrpcTransport as CampaignLabelServiceGrpcTransport

__all__ = ["CampaignLabelServiceTransport", "CampaignLabelServiceGrpcTransport"]



from .base import CustomAudienceServiceTransport as CustomAudienceServiceTransport
from .grpc import (
    CustomAudienceServiceGrpcTransport as CustomAudienceServiceGrpcTransport,
)

__all__ = ["CustomAudienceServiceTransport", "CustomAudienceServiceGrpcTransport"]



from .base import (
    ConversionValueRuleServiceTransport as ConversionValueRuleServiceTransport,
)
from .grpc import (
    ConversionValueRuleServiceGrpcTransport as ConversionValueRuleServiceGrpcTransport,
)

__all__ = [
    "ConversionValueRuleServiceTransport",
    "ConversionValueRuleServiceGrpcTransport",
]



from .base import SharedSetServiceTransport as SharedSetServiceTransport
from .grpc import SharedSetServiceGrpcTransport as SharedSetServiceGrpcTransport

__all__ = ["SharedSetServiceTransport", "SharedSetServiceGrpcTransport"]



from .base import ConversionUploadServiceTransport as ConversionUploadServiceTransport
from .grpc import (
    ConversionUploadServiceGrpcTransport as ConversionUploadServiceGrpcTransport,
)

__all__ = ["ConversionUploadServiceTransport", "ConversionUploadServiceGrpcTransport"]



from .base import CampaignSharedSetServiceTransport as CampaignSharedSetServiceTransport
from .grpc import (
    CampaignSharedSetServiceGrpcTransport as CampaignSharedSetServiceGrpcTransport,
)

__all__ = ["CampaignSharedSetServiceTransport", "CampaignSharedSetServiceGrpcTransport"]



from .base import CampaignGroupServiceTransport as CampaignGroupServiceTransport
from .grpc import CampaignGroupServiceGrpcTransport as CampaignGroupServiceGrpcTransport

__all__ = ["CampaignGroupServiceTransport", "CampaignGroupServiceGrpcTransport"]



from .client import (
    CustomerSkAdNetworkConversionValueSchemaServiceClient as CustomerSkAdNetworkConversionValueSchemaServiceClient,
)

__all__ = ["CustomerSkAdNetworkConversionValueSchemaServiceClient"]



from .base import (
    BiddingDataExclusionServiceTransport as BiddingDataExclusionServiceTransport,
)
from .grpc import (
    BiddingDataExclusionServiceGrpcTransport as BiddingDataExclusionServiceGrpcTransport,
)

__all__ = [
    "BiddingDataExclusionServiceTransport",
    "BiddingDataExclusionServiceGrpcTransport",
]



from .base import (
    AdGroupExtensionSettingServiceTransport as AdGroupExtensionSettingServiceTransport,
)
from .grpc import (
    AdGroupExtensionSettingServiceGrpcTransport as AdGroupExtensionSettingServiceGrpcTransport,
)

__all__ = [
    "AdGroupExtensionSettingServiceTransport",
    "AdGroupExtensionSettingServiceGrpcTransport",
]



from .base import CustomerServiceTransport as CustomerServiceTransport
from .grpc import CustomerServiceGrpcTransport as CustomerServiceGrpcTransport

__all__ = ["CustomerServiceTransport", "CustomerServiceGrpcTransport"]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v17.enums.types.response_content_type import (
    ResponseContentTypeEnum,
)
from google.ads.googleads.v17.resources.types.ad_group_criterion_customizer import (
    AdGroupCriterionCustomizer,
)

_M = TypeVar("_M")

class AdGroupCriterionCustomizerOperation(proto.Message):
    create: AdGroupCriterionCustomizer
    remove: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        create: AdGroupCriterionCustomizer = ...,
        remove: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["create", "remove"]
    ) -> bool: ...

class MutateAdGroupCriterionCustomizerResult(proto.Message):
    resource_name: str
    ad_group_criterion_customizer: AdGroupCriterionCustomizer
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        ad_group_criterion_customizer: AdGroupCriterionCustomizer = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name", "ad_group_criterion_customizer"]
    ) -> bool: ...

class MutateAdGroupCriterionCustomizersRequest(proto.Message):
    customer_id: str
    operations: MutableSequence[AdGroupCriterionCustomizerOperation]
    partial_failure: bool
    validate_only: bool
    response_content_type: ResponseContentTypeEnum.ResponseContentType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        operations: MutableSequence[AdGroupCriterionCustomizerOperation] = ...,
        partial_failure: bool = ...,
        validate_only: bool = ...,
        response_content_type: ResponseContentTypeEnum.ResponseContentType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "customer_id",
            "operations",
            "partial_failure",
            "validate_only",
            "response_content_type",
        ],
    ) -> bool: ...

class MutateAdGroupCriterionCustomizersResponse(proto.Message):
    results: MutableSequence[MutateAdGroupCriterionCustomizerResult]
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        results: MutableSequence[MutateAdGroupCriterionCustomizerResult] = ...,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["results", "partial_failure_error"]
    ) -> bool: ...



from .base import FeedMappingServiceTransport as FeedMappingServiceTransport
from .grpc import FeedMappingServiceGrpcTransport as FeedMappingServiceGrpcTransport

__all__ = ["FeedMappingServiceTransport", "FeedMappingServiceGrpcTransport"]



from .base import (
    AccountBudgetProposalServiceTransport as AccountBudgetProposalServiceTransport,
)
from .grpc import (
    AccountBudgetProposalServiceGrpcTransport as AccountBudgetProposalServiceGrpcTransport,
)

__all__ = [
    "AccountBudgetProposalServiceTransport",
    "AccountBudgetProposalServiceGrpcTransport",
]



from .base import CampaignServiceTransport as CampaignServiceTransport
from .grpc import CampaignServiceGrpcTransport as CampaignServiceGrpcTransport

__all__ = ["CampaignServiceTransport", "CampaignServiceGrpcTransport"]



from .base import (
    RecommendationSubscriptionServiceTransport as RecommendationSubscriptionServiceTransport,
)
from .grpc import (
    RecommendationSubscriptionServiceGrpcTransport as RecommendationSubscriptionServiceGrpcTransport,
)

__all__ = [
    "RecommendationSubscriptionServiceTransport",
    "RecommendationSubscriptionServiceGrpcTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

_M = TypeVar("_M")

class AppendLeadConversationRequest(proto.Message):
    customer_id: str
    conversations: MutableSequence[Conversation]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        conversations: MutableSequence[Conversation] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "conversations"]
    ) -> bool: ...

class AppendLeadConversationResponse(proto.Message):
    responses: MutableSequence[ConversationOrError]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        responses: MutableSequence[ConversationOrError] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["responses"]
    ) -> bool: ...

class Conversation(proto.Message):
    local_services_lead: str
    text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        local_services_lead: str = ...,
        text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["local_services_lead", "text"]
    ) -> bool: ...

class ConversationOrError(proto.Message):
    local_services_lead_conversation: str
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        local_services_lead_conversation: str = ...,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["local_services_lead_conversation", "partial_failure_error"]
    ) -> bool: ...



from .base import CustomInterestServiceTransport as CustomInterestServiceTransport
from .grpc import (
    CustomInterestServiceGrpcTransport as CustomInterestServiceGrpcTransport,
)

__all__ = ["CustomInterestServiceTransport", "CustomInterestServiceGrpcTransport"]



import types
from typing import Dict, MutableSequence, Sequence, Tuple, Type

from _typeshed import Incomplete
from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v16.services.types import asset_set_asset_service

from .transports.base import AssetSetAssetServiceTransport

__all__ = ["AssetSetAssetServiceClient"]

class AssetSetAssetServiceClientMeta(type):
    def get_transport_class(
        cls, label: str | None = None
    ) -> type[AssetSetAssetServiceTransport]: ...

class AssetSetAssetServiceClient(metaclass=AssetSetAssetServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @property
    def transport(self) -> AssetSetAssetServiceTransport: ...
    def __enter__(self) -> AssetSetAssetServiceClient: ...
    def __exit__(
        self,
        type: type[BaseException] | None,
        value: BaseException | None,
        traceback: types.TracebackType | None,
    ) -> None: ...
    @staticmethod
    def asset_path(customer_id: str, asset_id: str) -> str: ...
    @staticmethod
    def parse_asset_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def asset_set_path(customer_id: str, asset_set_id: str) -> str: ...
    @staticmethod
    def parse_asset_set_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def asset_set_asset_path(
        customer_id: str, asset_set_id: str, asset_id: str
    ) -> str: ...
    @staticmethod
    def parse_asset_set_asset_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> dict[str, str]: ...
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str | AssetSetAssetServiceTransport | None = None,
        client_options: client_options_lib.ClientOptions | dict | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    def mutate_asset_set_assets(
        self,
        request: asset_set_asset_service.MutateAssetSetAssetsRequest
        | dict
        | None = None,
        *,
        customer_id: str | None = None,
        operations: MutableSequence[asset_set_asset_service.AssetSetAssetOperation]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str]] = (),
    ) -> asset_set_asset_service.MutateAssetSetAssetsResponse: ...



from .base import CustomerLabelServiceTransport as CustomerLabelServiceTransport
from .grpc import CustomerLabelServiceGrpcTransport as CustomerLabelServiceGrpcTransport

__all__ = ["CustomerLabelServiceTransport", "CustomerLabelServiceGrpcTransport"]



from .base import AudienceServiceTransport as AudienceServiceTransport
from .grpc import AudienceServiceGrpcTransport as AudienceServiceGrpcTransport

__all__ = ["AudienceServiceTransport", "AudienceServiceGrpcTransport"]



from .base import (
    SmartCampaignSettingServiceTransport as SmartCampaignSettingServiceTransport,
)
from .grpc import (
    SmartCampaignSettingServiceGrpcTransport as SmartCampaignSettingServiceGrpcTransport,
)

__all__ = [
    "SmartCampaignSettingServiceTransport",
    "SmartCampaignSettingServiceGrpcTransport",
]



from .base import (
    CampaignExtensionSettingServiceTransport as CampaignExtensionSettingServiceTransport,
)
from .grpc import (
    CampaignExtensionSettingServiceGrpcTransport as CampaignExtensionSettingServiceGrpcTransport,
)

__all__ = [
    "CampaignExtensionSettingServiceTransport",
    "CampaignExtensionSettingServiceGrpcTransport",
]



from .base import ShareablePreviewServiceTransport as ShareablePreviewServiceTransport
from .grpc import (
    ShareablePreviewServiceGrpcTransport as ShareablePreviewServiceGrpcTransport,
)

__all__ = ["ShareablePreviewServiceTransport", "ShareablePreviewServiceGrpcTransport"]



from .base import CampaignAssetSetServiceTransport as CampaignAssetSetServiceTransport
from .grpc import (
    CampaignAssetSetServiceGrpcTransport as CampaignAssetSetServiceGrpcTransport,
)

__all__ = ["CampaignAssetSetServiceTransport", "CampaignAssetSetServiceGrpcTransport"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v17.common.types.simulation import (
    BudgetSimulationPointList,
    CpcBidSimulationPointList,
    TargetCpaSimulationPointList,
    TargetImpressionShareSimulationPointList,
    TargetRoasSimulationPointList,
)
from google.ads.googleads.v17.enums.types.simulation_modification_method import (
    SimulationModificationMethodEnum,
)
from google.ads.googleads.v17.enums.types.simulation_type import SimulationTypeEnum

_M = TypeVar("_M")

class CampaignSimulation(proto.Message):
    resource_name: str
    campaign_id: int
    type_: SimulationTypeEnum.SimulationType
    modification_method: SimulationModificationMethodEnum.SimulationModificationMethod
    start_date: str
    end_date: str
    cpc_bid_point_list: CpcBidSimulationPointList
    target_cpa_point_list: TargetCpaSimulationPointList
    target_roas_point_list: TargetRoasSimulationPointList
    target_impression_share_point_list: TargetImpressionShareSimulationPointList
    budget_point_list: BudgetSimulationPointList
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        campaign_id: int = ...,
        type_: SimulationTypeEnum.SimulationType = ...,
        modification_method: SimulationModificationMethodEnum.SimulationModificationMethod = ...,
        start_date: str = ...,
        end_date: str = ...,
        cpc_bid_point_list: CpcBidSimulationPointList = ...,
        target_cpa_point_list: TargetCpaSimulationPointList = ...,
        target_roas_point_list: TargetRoasSimulationPointList = ...,
        target_impression_share_point_list: TargetImpressionShareSimulationPointList = ...,
        budget_point_list: BudgetSimulationPointList = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "campaign_id",
            "type_",
            "modification_method",
            "start_date",
            "end_date",
            "cpc_bid_point_list",
            "target_cpa_point_list",
            "target_roas_point_list",
            "target_impression_share_point_list",
            "budget_point_list",
        ],
    ) -> bool: ...



from .base import PaymentsAccountServiceTransport as PaymentsAccountServiceTransport
from .grpc import (
    PaymentsAccountServiceGrpcTransport as PaymentsAccountServiceGrpcTransport,
)

__all__ = ["PaymentsAccountServiceTransport", "PaymentsAccountServiceGrpcTransport"]



__all__ = [
    "ActivityCityInfo",
    "ActivityCountryInfo",
    "ActivityIdInfo",
    "ActivityRatingInfo",
    "ActivityStateInfo",
    "AdAssetPolicySummary",
    "AdCallToActionAsset",
    "AdDiscoveryCarouselCardAsset",
    "AdImageAsset",
    "AdMediaBundleAsset",
    "AdScheduleInfo",
    "AdTextAsset",
    "AdVideoAsset",
    "AddressInfo",
    "AffiliateLocationFeedItem",
    "AgeDimension",
    "AgeRangeInfo",
    "AgeSegment",
    "AppAdInfo",
    "AppEngagementAdInfo",
    "AppFeedItem",
    "AppPaymentModelInfo",
    "AppPreRegistrationAdInfo",
    "AssetDisapproved",
    "AssetInteractionTarget",
    "AssetLinkPrimaryStatusDetails",
    "AssetUsage",
    "AudienceDimension",
    "AudienceExclusionDimension",
    "AudienceInfo",
    "AudienceSegment",
    "AudienceSegmentDimension",
    "BasicUserListInfo",
    "BookOnGoogleAsset",
    "BrandInfo",
    "BrandListInfo",
    "BudgetCampaignAssociationStatus",
    "BudgetSimulationPoint",
    "BudgetSimulationPointList",
    "BusinessNameFilter",
    "BusinessProfileBusinessNameFilter",
    "BusinessProfileLocation",
    "BusinessProfileLocationGroup",
    "BusinessProfileLocationSet",
    "CallAdInfo",
    "CallAsset",
    "CallFeedItem",
    "CallToActionAsset",
    "CalloutAsset",
    "CalloutFeedItem",
    "CarrierInfo",
    "ChainFilter",
    "ChainLocationGroup",
    "ChainSet",
    "ClickLocation",
    "CombinedAudienceInfo",
    "Commission",
    "ConceptGroup",
    "Consent",
    "ContentLabelInfo",
    "CpcBidSimulationPoint",
    "CpcBidSimulationPointList",
    "CpvBidSimulationPoint",
    "CpvBidSimulationPointList",
    "CriterionCategoryAvailability",
    "CriterionCategoryChannelAvailability",
    "CriterionCategoryLocaleAvailability",
    "CrmBasedUserListInfo",
    "CustomAffinityInfo",
    "CustomAudienceInfo",
    "CustomAudienceSegment",
    "CustomIntentInfo",
    "CustomParameter",
    "CustomerMatchUserListMetadata",
    "CustomizerValue",
    "DateRange",
    "DemandGenProductAdInfo",
    "DetailedDemographicSegment",
    "DeviceInfo",
    "DiscoveryCarouselAdInfo",
    "DiscoveryCarouselCardAsset",
    "DiscoveryMultiAssetAdInfo",
    "DiscoveryVideoResponsiveAdInfo",
    "DisplayUploadAdInfo",
    "DynamicAffiliateLocationSetFilter",
    "DynamicBusinessProfileLocationGroupFilter",
    "DynamicCustomAsset",
    "DynamicEducationAsset",
    "DynamicFlightsAsset",
    "DynamicHotelsAndRentalsAsset",
    "DynamicJobsAsset",
    "DynamicLocalAsset",
    "DynamicLocationSetFilter",
    "DynamicRealEstateAsset",
    "DynamicTravelAsset",
    "EnhancedCpc",
    "EventAttribute",
    "EventItemAttribute",
    "ExclusionSegment",
    "ExpandedDynamicSearchAdInfo",
    "ExpandedTextAdInfo",
    "FinalAppUrl",
    "FlexibleRuleOperandInfo",
    "FlexibleRuleUserListInfo",
    "FrequencyCapEntry",
    "FrequencyCapKey",
    "GenderDimension",
    "GenderInfo",
    "GeoPointInfo",
    "HistoricalMetricsOptions",
    "HotelAdInfo",
    "HotelAdvanceBookingWindowInfo",
    "HotelCalloutAsset",
    "HotelCalloutFeedItem",
    "HotelCheckInDateRangeInfo",
    "HotelCheckInDayInfo",
    "HotelCityInfo",
    "HotelClassInfo",
    "HotelCountryRegionInfo",
    "HotelDateSelectionTypeInfo",
    "HotelIdInfo",
    "HotelLengthOfStayInfo",
    "HotelPropertyAsset",
    "HotelStateInfo",
    "HouseholdIncomeDimension",
    "ImageAdInfo",
    "ImageAsset",
    "ImageDimension",
    "ImageFeedItem",
    "InFeedVideoAdInfo",
    "IncomeRangeInfo",
    "InteractionTypeInfo",
    "IpBlockInfo",
    "ItemAttribute",
    "Keyword",
    "KeywordAnnotations",
    "KeywordConcept",
    "KeywordInfo",
    "KeywordPlanAggregateMetricResults",
    "KeywordPlanAggregateMetrics",
    "KeywordPlanDeviceSearches",
    "KeywordPlanHistoricalMetrics",
    "KeywordThemeInfo",
    "LanguageInfo",
    "LeadFormAsset",
    "LeadFormCustomQuestionField",
    "LeadFormDeliveryMethod",
    "LeadFormField",
    "LeadFormSingleChoiceAnswers",
    "LegacyAppInstallAdInfo",
    "LegacyResponsiveDisplayAdInfo",
    "LifeEventSegment",
    "LifecycleGoalValueSettings",
    "ListingDimensionInfo",
    "ListingDimensionPath",
    "ListingGroupInfo",
    "ListingScopeInfo",
    "LocalAdInfo",
    "LocalServiceIdInfo",
    "LocalServicesDocumentReadOnly",
    "LocationAsset",
    "LocationFeedItem",
    "LocationGroupInfo",
    "LocationInfo",
    "LocationSet",
    "LogicalUserListInfo",
    "LogicalUserListOperandInfo",
    "LookalikeUserListInfo",
    "ManualCpa",
    "ManualCpc",
    "ManualCpm",
    "ManualCpv",
    "MapsLocationInfo",
    "MapsLocationSet",
    "MatchingFunction",
    "MaximizeConversionValue",
    "MaximizeConversions",
    "MediaBundleAsset",
    "MetricGoal",
    "Metrics",
    "MobileAppAsset",
    "MobileAppCategoryInfo",
    "MobileApplicationInfo",
    "MobileDeviceInfo",
    "Money",
    "MonthlySearchVolume",
    "NegativeKeywordListInfo",
    "OfflineUserAddressInfo",
    "Operand",
    "OperatingSystemVersionInfo",
    "PageFeedAsset",
    "ParentalStatusDimension",
    "ParentalStatusInfo",
    "PercentCpc",
    "PercentCpcBidSimulationPoint",
    "PercentCpcBidSimulationPointList",
    "PlacementInfo",
    "PolicySummary",
    "PolicyTopicConstraint",
    "PolicyTopicEntry",
    "PolicyTopicEvidence",
    "PolicyValidationParameter",
    "PolicyViolationKey",
    "PriceAsset",
    "PriceFeedItem",
    "PriceOffer",
    "PriceOffering",
    "ProductBrandInfo",
    "ProductCategoryInfo",
    "ProductChannelExclusivityInfo",
    "ProductChannelInfo",
    "ProductConditionInfo",
    "ProductCustomAttributeInfo",
    "ProductGroupingInfo",
    "ProductItemIdInfo",
    "ProductLabelsInfo",
    "ProductLegacyConditionInfo",
    "ProductTypeFullInfo",
    "ProductTypeInfo",
    "PromotionAsset",
    "PromotionFeedItem",
    "ProximityInfo",
    "RealTimeBiddingSetting",
    "ResponsiveDisplayAdControlSpec",
    "ResponsiveDisplayAdInfo",
    "ResponsiveSearchAdInfo",
    "RuleBasedUserListInfo",
    "SearchThemeInfo",
    "SearchVolumeRange",
    "Segments",
    "ShoppingComparisonListingAdInfo",
    "ShoppingLoyalty",
    "ShoppingProductAdInfo",
    "ShoppingSmartAdInfo",
    "SimilarUserListInfo",
    "SitelinkAsset",
    "SitelinkFeedItem",
    "SkAdNetworkSourceApp",
    "SmartCampaignAdInfo",
    "StoreAttribute",
    "StoreSalesMetadata",
    "StoreSalesThirdPartyMetadata",
    "StructuredSnippetAsset",
    "StructuredSnippetFeedItem",
    "TagSnippet",
    "TargetCpa",
    "TargetCpaSimulationPoint",
    "TargetCpaSimulationPointList",
    "TargetCpm",
    "TargetCpmTargetFrequencyGoal",
    "TargetImpressionShare",
    "TargetImpressionShareSimulationPoint",
    "TargetImpressionShareSimulationPointList",
    "TargetRestriction",
    "TargetRestrictionOperation",
    "TargetRoas",
    "TargetRoasSimulationPoint",
    "TargetRoasSimulationPointList",
    "TargetSpend",
    "TargetingSetting",
    "TextAdInfo",
    "TextAsset",
    "TextLabel",
    "TextMessageFeedItem",
    "TopicInfo",
    "TransactionAttribute",
    "TravelAdInfo",
    "UnknownListingDimensionInfo",
    "UrlCollection",
    "UserAttribute",
    "UserData",
    "UserIdentifier",
    "UserInterestInfo",
    "UserInterestSegment",
    "UserListActionInfo",
    "UserListDateRuleItemInfo",
    "UserListInfo",
    "UserListLogicalRuleInfo",
    "UserListNumberRuleItemInfo",
    "UserListRuleInfo",
    "UserListRuleItemGroupInfo",
    "UserListRuleItemInfo",
    "UserListSegment",
    "UserListStringRuleItemInfo",
    "Value",
    "VideoAdInfo",
    "VideoBumperInStreamAdInfo",
    "VideoNonSkippableInStreamAdInfo",
    "VideoOutstreamAdInfo",
    "VideoResponsiveAdInfo",
    "VideoTrueViewInStreamAdInfo",
    "WebhookDelivery",
    "WebpageConditionInfo",
    "WebpageInfo",
    "WebpageSampleInfo",
    "YearMonth",
    "YearMonthRange",
    "YouTubeChannelInfo",
    "YouTubeVideoInfo",
    "YoutubeVideoAsset",
]

# Names in __all__ with no definition:
#   ActivityCityInfo
#   ActivityCountryInfo
#   ActivityIdInfo
#   ActivityRatingInfo
#   ActivityStateInfo
#   AdAssetPolicySummary
#   AdCallToActionAsset
#   AdDiscoveryCarouselCardAsset
#   AdImageAsset
#   AdMediaBundleAsset
#   AdScheduleInfo
#   AdTextAsset
#   AdVideoAsset
#   AddressInfo
#   AffiliateLocationFeedItem
#   AgeDimension
#   AgeRangeInfo
#   AgeSegment
#   AppAdInfo
#   AppEngagementAdInfo
#   AppFeedItem
#   AppPaymentModelInfo
#   AppPreRegistrationAdInfo
#   AssetDisapproved
#   AssetInteractionTarget
#   AssetLinkPrimaryStatusDetails
#   AssetUsage
#   AudienceDimension
#   AudienceExclusionDimension
#   AudienceInfo
#   AudienceSegment
#   AudienceSegmentDimension
#   BasicUserListInfo
#   BookOnGoogleAsset
#   BrandInfo
#   BrandListInfo
#   BudgetCampaignAssociationStatus
#   BudgetSimulationPoint
#   BudgetSimulationPointList
#   BusinessNameFilter
#   BusinessProfileBusinessNameFilter
#   BusinessProfileLocation
#   BusinessProfileLocationGroup
#   BusinessProfileLocationSet
#   CallAdInfo
#   CallAsset
#   CallFeedItem
#   CallToActionAsset
#   CalloutAsset
#   CalloutFeedItem
#   CarrierInfo
#   ChainFilter
#   ChainLocationGroup
#   ChainSet
#   ClickLocation
#   CombinedAudienceInfo
#   Commission
#   ConceptGroup
#   Consent
#   ContentLabelInfo
#   CpcBidSimulationPoint
#   CpcBidSimulationPointList
#   CpvBidSimulationPoint
#   CpvBidSimulationPointList
#   CriterionCategoryAvailability
#   CriterionCategoryChannelAvailability
#   CriterionCategoryLocaleAvailability
#   CrmBasedUserListInfo
#   CustomAffinityInfo
#   CustomAudienceInfo
#   CustomAudienceSegment
#   CustomIntentInfo
#   CustomParameter
#   CustomerMatchUserListMetadata
#   CustomizerValue
#   DateRange
#   DemandGenProductAdInfo
#   DetailedDemographicSegment
#   DeviceInfo
#   DiscoveryCarouselAdInfo
#   DiscoveryCarouselCardAsset
#   DiscoveryMultiAssetAdInfo
#   DiscoveryVideoResponsiveAdInfo
#   DisplayUploadAdInfo
#   DynamicAffiliateLocationSetFilter
#   DynamicBusinessProfileLocationGroupFilter
#   DynamicCustomAsset
#   DynamicEducationAsset
#   DynamicFlightsAsset
#   DynamicHotelsAndRentalsAsset
#   DynamicJobsAsset
#   DynamicLocalAsset
#   DynamicLocationSetFilter
#   DynamicRealEstateAsset
#   DynamicTravelAsset
#   EnhancedCpc
#   EventAttribute
#   EventItemAttribute
#   ExclusionSegment
#   ExpandedDynamicSearchAdInfo
#   ExpandedTextAdInfo
#   FinalAppUrl
#   FlexibleRuleOperandInfo
#   FlexibleRuleUserListInfo
#   FrequencyCapEntry
#   FrequencyCapKey
#   GenderDimension
#   GenderInfo
#   GeoPointInfo
#   HistoricalMetricsOptions
#   HotelAdInfo
#   HotelAdvanceBookingWindowInfo
#   HotelCalloutAsset
#   HotelCalloutFeedItem
#   HotelCheckInDateRangeInfo
#   HotelCheckInDayInfo
#   HotelCityInfo
#   HotelClassInfo
#   HotelCountryRegionInfo
#   HotelDateSelectionTypeInfo
#   HotelIdInfo
#   HotelLengthOfStayInfo
#   HotelPropertyAsset
#   HotelStateInfo
#   HouseholdIncomeDimension
#   ImageAdInfo
#   ImageAsset
#   ImageDimension
#   ImageFeedItem
#   InFeedVideoAdInfo
#   IncomeRangeInfo
#   InteractionTypeInfo
#   IpBlockInfo
#   ItemAttribute
#   Keyword
#   KeywordAnnotations
#   KeywordConcept
#   KeywordInfo
#   KeywordPlanAggregateMetricResults
#   KeywordPlanAggregateMetrics
#   KeywordPlanDeviceSearches
#   KeywordPlanHistoricalMetrics
#   KeywordThemeInfo
#   LanguageInfo
#   LeadFormAsset
#   LeadFormCustomQuestionField
#   LeadFormDeliveryMethod
#   LeadFormField
#   LeadFormSingleChoiceAnswers
#   LegacyAppInstallAdInfo
#   LegacyResponsiveDisplayAdInfo
#   LifeEventSegment
#   LifecycleGoalValueSettings
#   ListingDimensionInfo
#   ListingDimensionPath
#   ListingGroupInfo
#   ListingScopeInfo
#   LocalAdInfo
#   LocalServiceIdInfo
#   LocalServicesDocumentReadOnly
#   LocationAsset
#   LocationFeedItem
#   LocationGroupInfo
#   LocationInfo
#   LocationSet
#   LogicalUserListInfo
#   LogicalUserListOperandInfo
#   LookalikeUserListInfo
#   ManualCpa
#   ManualCpc
#   ManualCpm
#   ManualCpv
#   MapsLocationInfo
#   MapsLocationSet
#   MatchingFunction
#   MaximizeConversionValue
#   MaximizeConversions
#   MediaBundleAsset
#   MetricGoal
#   Metrics
#   MobileAppAsset
#   MobileAppCategoryInfo
#   MobileApplicationInfo
#   MobileDeviceInfo
#   Money
#   MonthlySearchVolume
#   NegativeKeywordListInfo
#   OfflineUserAddressInfo
#   Operand
#   OperatingSystemVersionInfo
#   PageFeedAsset
#   ParentalStatusDimension
#   ParentalStatusInfo
#   PercentCpc
#   PercentCpcBidSimulationPoint
#   PercentCpcBidSimulationPointList
#   PlacementInfo
#   PolicySummary
#   PolicyTopicConstraint
#   PolicyTopicEntry
#   PolicyTopicEvidence
#   PolicyValidationParameter
#   PolicyViolationKey
#   PriceAsset
#   PriceFeedItem
#   PriceOffer
#   PriceOffering
#   ProductBrandInfo
#   ProductCategoryInfo
#   ProductChannelExclusivityInfo
#   ProductChannelInfo
#   ProductConditionInfo
#   ProductCustomAttributeInfo
#   ProductGroupingInfo
#   ProductItemIdInfo
#   ProductLabelsInfo
#   ProductLegacyConditionInfo
#   ProductTypeFullInfo
#   ProductTypeInfo
#   PromotionAsset
#   PromotionFeedItem
#   ProximityInfo
#   RealTimeBiddingSetting
#   ResponsiveDisplayAdControlSpec
#   ResponsiveDisplayAdInfo
#   ResponsiveSearchAdInfo
#   RuleBasedUserListInfo
#   SearchThemeInfo
#   SearchVolumeRange
#   Segments
#   ShoppingComparisonListingAdInfo
#   ShoppingLoyalty
#   ShoppingProductAdInfo
#   ShoppingSmartAdInfo
#   SimilarUserListInfo
#   SitelinkAsset
#   SitelinkFeedItem
#   SkAdNetworkSourceApp
#   SmartCampaignAdInfo
#   StoreAttribute
#   StoreSalesMetadata
#   StoreSalesThirdPartyMetadata
#   StructuredSnippetAsset
#   StructuredSnippetFeedItem
#   TagSnippet
#   TargetCpa
#   TargetCpaSimulationPoint
#   TargetCpaSimulationPointList
#   TargetCpm
#   TargetCpmTargetFrequencyGoal
#   TargetImpressionShare
#   TargetImpressionShareSimulationPoint
#   TargetImpressionShareSimulationPointList
#   TargetRestriction
#   TargetRestrictionOperation
#   TargetRoas
#   TargetRoasSimulationPoint
#   TargetRoasSimulationPointList
#   TargetSpend
#   TargetingSetting
#   TextAdInfo
#   TextAsset
#   TextLabel
#   TextMessageFeedItem
#   TopicInfo
#   TransactionAttribute
#   TravelAdInfo
#   UnknownListingDimensionInfo
#   UrlCollection
#   UserAttribute
#   UserData
#   UserIdentifier
#   UserInterestInfo
#   UserInterestSegment
#   UserListActionInfo
#   UserListDateRuleItemInfo
#   UserListInfo
#   UserListLogicalRuleInfo
#   UserListNumberRuleItemInfo
#   UserListRuleInfo
#   UserListRuleItemGroupInfo
#   UserListRuleItemInfo
#   UserListSegment
#   UserListStringRuleItemInfo
#   Value
#   VideoAdInfo
#   VideoBumperInStreamAdInfo
#   VideoNonSkippableInStreamAdInfo
#   VideoOutstreamAdInfo
#   VideoResponsiveAdInfo
#   VideoTrueViewInStreamAdInfo
#   WebhookDelivery
#   WebpageConditionInfo
#   WebpageInfo
#   WebpageSampleInfo
#   YearMonth
#   YearMonthRange
#   YouTubeChannelInfo
#   YouTubeVideoInfo
#   YoutubeVideoAsset



from .base import AssetSetAssetServiceTransport as AssetSetAssetServiceTransport
from .grpc import AssetSetAssetServiceGrpcTransport as AssetSetAssetServiceGrpcTransport

__all__ = ["AssetSetAssetServiceTransport", "AssetSetAssetServiceGrpcTransport"]



from typing import Callable, Sequence, Tuple

import grpc
from google.api_core import gapic_v1
from google.auth import credentials as ga_credentials

from google.ads.googleads.v16.services.types import customer_customizer_service

from .base import CustomerCustomizerServiceTransport

__all__ = ["CustomerCustomizerServiceGrpcTransport"]

class CustomerCustomizerServiceGrpcTransport(CustomerCustomizerServiceTransport):
    def __init__(
        self,
        *,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        channel: grpc.Channel | None = None,
        api_mtls_endpoint: str | None = None,
        client_cert_source: Callable[[], tuple[bytes, bytes]] | None = None,
        ssl_channel_credentials: grpc.ChannelCredentials | None = None,
        client_cert_source_for_mtls: Callable[[], tuple[bytes, bytes]] | None = None,
        quota_project_id: str | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
        always_use_jwt_access: bool | None = False,
    ) -> None: ...
    @classmethod
    def create_channel(
        cls,
        host: str = "googleads.googleapis.com",
        credentials: ga_credentials.Credentials | None = None,
        credentials_file: str | None = None,
        scopes: Sequence[str] | None = None,
        quota_project_id: str | None = None,
        **kwargs,
    ) -> grpc.Channel: ...
    @property
    def grpc_channel(self) -> grpc.Channel: ...
    @property
    def mutate_customer_customizers(
        self,
    ) -> Callable[
        [customer_customizer_service.MutateCustomerCustomizersRequest],
        customer_customizer_service.MutateCustomerCustomizersResponse,
    ]: ...
    def close(self) -> None: ...



from .base import CampaignBudgetServiceTransport as CampaignBudgetServiceTransport
from .grpc import (
    CampaignBudgetServiceGrpcTransport as CampaignBudgetServiceGrpcTransport,
)

__all__ = ["CampaignBudgetServiceTransport", "CampaignBudgetServiceGrpcTransport"]
